@@ -30,7 +30,8 @@
 
 int main(int argc, char **argv)
 {
-    QApplication app(argc, argv); // PORTING SCRIPT: move this to before the KAboutData initialization
+    QApplication app(argc, argv);
+    KLocalizedString::setApplicationDomain("kdesvn");
     KAboutData aboutData(QStringLiteral("kdesvnaskpass"), i18n("kdesvnaskpass"), QStringLiteral("0.2"),
                          i18n("ssh-askpass for kdesvn"),
                          KAboutLicense::LicenseKey::LGPL,
@@ -39,10 +40,10 @@ int main(int argc, char **argv)
     KAboutData::setApplicationData(aboutData);
     parser.addVersionOption();
     parser.addHelpOption();
-    aboutData.setupCommandLine(&parser);
-    aboutData.processCommandLine(&parser);
     parser.addPositionalArgument(QStringLiteral("[prompt]"), i18n("Prompt"));
+    aboutData.setupCommandLine(&parser);
     parser.process(app);
+    aboutData.processCommandLine(&parser);
     // no need for session management
     //app.disableSessionManagement();
 
@@ -54,8 +55,8 @@ int main(int argc, char **argv)
         prompt = i18n("Please enter your password below.");
     } else {
         prompt = parser.positionalArguments().at(0);
-        if (prompt.contains("Bad passphrase", Qt::CaseInsensitive) ||
-                prompt.contains("Permission denied", Qt::CaseInsensitive)) {
+        if (prompt.contains(QLatin1String("Bad passphrase"), Qt::CaseInsensitive) ||
+                prompt.contains(QLatin1String("Permission denied"), Qt::CaseInsensitive)) {
             error = true;
         }
         kfile = prompt.section(QLatin1Char(' '), -2).remove(QLatin1Char(':')).simplified();
@@ -70,9 +71,9 @@ int main(int argc, char **argv)
     }
 
     if (pw.isEmpty()) {
-        QPointer<KPasswordDialog> dlg(new KPasswordDialog(0, (wallet ? KPasswordDialog::ShowKeepPassword : KPasswordDialog::NoFlags)));
+        QPointer<KPasswordDialog> dlg(new KPasswordDialog(nullptr, (wallet ? KPasswordDialog::ShowKeepPassword : KPasswordDialog::NoFlags)));
         dlg->setPrompt(prompt);
-        dlg->setWindowTitle(i18n("Password"));
+        dlg->setWindowTitle(i18nc("@title:window", "Password"));
         if (dlg->exec() != KPasswordDialog::Accepted) {
             delete dlg;
             return 1;
@@ -91,7 +92,7 @@ int main(int argc, char **argv)
     QTextStream out(stdout);
     out << pw;
     /* cleanup memory */
-    pw.replace(0, pw.length(), "0");
+    pw.replace(0, pw.length(), QLatin1Char('0'));
     return 0;
 }
 
