@@ -25,7 +25,9 @@
 #include "kdesvn-config.h"
 
 #include <KProcess>
+#include <QCoreApplication>
 #include <QRegExp>
+#include <QStandardPaths>
 #include "kdesvn_debug.h"
 
 // initialize static member variables
@@ -47,7 +49,7 @@ public:
 };
 
 SshAgent::SshAgent(QObject *parent)
-    : QObject(parent), sshAgent(0)
+    : QObject(parent), sshAgent(nullptr)
 {
     static SshClean st;
 }
@@ -91,12 +93,18 @@ void SshAgent::askPassEnv()
     qCDebug(KDESVN_LOG) << "Using test askpass" << endl;
     qputenv("SSH_ASKPASS", FORCE_ASKPASS);
 #else
-    QByteArray pro = BIN_INSTALL_DIR;
-    if (!pro.endsWith('/')) {
-        pro.append('/');
+    const QString kdesvnAskPass(QStringLiteral("kdesvnaskpass"));
+    // first search nearby us
+    QString askPassPath = QStandardPaths::findExecutable(kdesvnAskPass, {QCoreApplication::applicationDirPath()});
+    if (askPassPath.isEmpty()) {
+        // now search in PATH
+        askPassPath = QStandardPaths::findExecutable(kdesvnAskPass);
     }
-    pro.append("kdesvnaskpass");
-    qputenv("SSH_ASKPASS", pro);
+    if (askPassPath.isEmpty()) {
+        // ok, not found, but maybe ssh-agent does ...
+        askPassPath = kdesvnAskPass;
+    }
+    qputenv("SSH_ASKPASS", askPassPath.toLocal8Bit());
 #endif
 }
 
@@ -114,18 +122,18 @@ bool SshAgent::addSshIdentities(bool force)
     // add identities to ssh-agent
     KProcess proc;
 
-    proc.setEnv("SSH_AGENT_PID", m_pid);
-    proc.setEnv("SSH_AUTH_SOCK", m_authSock);
+    proc.setEnv(QStringLiteral("SSH_AGENT_PID"), m_pid);
+    proc.setEnv(QStringLiteral("SSH_AUTH_SOCK"), m_authSock);
 
 #ifdef FORCE_ASKPASS
     qCDebug(KDESVN_LOG) << "Using test askpass" << endl;
     proc.setEnv("SSH_ASKPASS", FORCE_ASKPASS);
 #else
     qCDebug(KDESVN_LOG) << "Using kdesvnaskpass" << endl;
-    proc.setEnv("SSH_ASKPASS", "kdesvnaskpass");
+    proc.setEnv(QStringLiteral("SSH_ASKPASS"), QStringLiteral("kdesvnaskpass"));
 #endif
 
-    proc << "ssh-add";
+    proc << QStringLiteral("ssh-add");
     proc.start();
     // endless
     proc.waitForFinished(-1);
@@ -141,11 +149,8 @@ void SshAgent::killSshAgent()
         return;
     }
 
-    KProcess proc;
-
-    proc << "kill" << m_pid;
-
-    proc.start();
+    QProcess proc;
+    proc.start(QStringLiteral("kill"), {m_pid});
     proc.waitForFinished();
 }
 
@@ -154,24 +159,22 @@ void SshAgent::slotProcessExited(int exitCode, QProcess::ExitStatus exitStatus)
     if (exitStatus != QProcess::NormalExit || exitCode != 0) {
         return;
     }
-    QRegExp cshPidRx("setenv SSH_AGENT_PID (\\d*);");
-    QRegExp cshSockRx("setenv SSH_AUTH_SOCK (.*);");
+    const QRegExp cshPidRx(QStringLiteral("setenv SSH_AGENT_PID (\\d*);"));
+    const QRegExp cshSockRx(QStringLiteral("setenv SSH_AUTH_SOCK (.*);"));
 
-    QRegExp bashPidRx("SSH_AGENT_PID=(\\d*).*");
-    QRegExp bashSockRx("SSH_AUTH_SOCK=(.*\\.\\d*);.*");
-    QStringList m_outputLines = m_Output.split('\n', QString::SkipEmptyParts);
+    const QRegExp bashPidRx(QStringLiteral("SSH_AGENT_PID=(\\d*).*"));
+    const QRegExp bashSockRx(QStringLiteral("SSH_AUTH_SOCK=(.*\\.\\d*);.*"));
+    const QStringList m_outputLines = m_Output.split(QLatin1Char('\n'), QString::SkipEmptyParts);
 
-    QStringList::Iterator it  = m_outputLines.begin();
-    QStringList::Iterator end = m_outputLines.end();
-    for (; it != end; ++it) {
+    for (const auto &outputLine : m_outputLines) {
         if (m_pid.isEmpty()) {
-            int pos = cshPidRx.indexIn(*it);
+            int pos = cshPidRx.indexIn(outputLine);
             if (pos > -1) {
                 m_pid = cshPidRx.cap(1);
                 continue;
             }
 
-            pos = bashPidRx.indexIn(*it);
+            pos = bashPidRx.indexIn(outputLine);
             if (pos > -1) {
                 m_pid = bashPidRx.cap(1);
                 continue;
@@ -179,13 +182,13 @@ void SshAgent::slotProcessExited(int exitCode, QProcess::ExitStatus exitStatus)
         }
 
         if (m_authSock.isEmpty()) {
-            int pos = cshSockRx.indexIn(*it);
+            int pos = cshSockRx.indexIn(outputLine);
             if (pos > -1) {
                 m_authSock = cshSockRx.cap(1);
                 continue;
             }
 
-            pos = bashSockRx.indexIn(*it);
+            pos = bashSockRx.indexIn(outputLine);
             if (pos > -1) {
                 m_authSock = bashSockRx.cap(1);
                 continue;
@@ -209,20 +212,20 @@ bool SshAgent::startSshAgent()
         return false;
     }
     sshAgent = new KProcess();
-    *sshAgent << "ssh-agent";
+    *sshAgent << QStringLiteral("ssh-agent");
 
     sshAgent->setOutputChannelMode(KProcess::MergedChannels);
 
-    connect(sshAgent, SIGNAL(finished(int,QProcess::ExitStatus)),
-            SLOT(slotProcessExited(int,QProcess::ExitStatus)));
-    connect(sshAgent, SIGNAL(readyReadStandardOutput()),
-            SLOT(slotReceivedStdout()));
+    connect(sshAgent, QOverload<int,QProcess::ExitStatus>::of(&KProcess::finished),
+            this, &SshAgent::slotProcessExited);
+    connect(sshAgent, &KProcess::readyReadStandardOutput,
+            this, &SshAgent::slotReceivedStdout);
     sshAgent->start();
     // wait for process to finish eg. backgrounding
     sshAgent->waitForFinished(-1);
     bool ok = (sshAgent->exitStatus() == QProcess::NormalExit && sshAgent->exitStatus() == 0);
     delete sshAgent;
-    sshAgent = 0;
+    sshAgent = nullptr;
 
     return ok;
 }
