@@ -60,7 +60,7 @@ K_PLUGIN_FACTORY_WITH_JSON(KdeSvndFactory,
     }
 
 kdesvnd::kdesvnd(QObject *parent, const QList<QVariant> &) : KDEDModule(parent),
-    m_uiserver("org.kde.JobViewServer", "/JobViewServer", QDBusConnection::sessionBus())
+    m_uiserver(QStringLiteral("org.kde.JobViewServer"), QStringLiteral("/JobViewServer"), QDBusConnection::sessionBus())
 {
     m_Listener = new KdesvndListener(this);
     new KdesvndAdaptor(this);
@@ -76,8 +76,11 @@ QStringList kdesvnd::getTopLevelActionMenu(const QStringList &urlList) const
     // we get correct urls here
     QList<QUrl> urls;
     urls.reserve(urlList.size());
-    Q_FOREACH(const QString &str, urlList) {
-        urls += QUrl(str);
+    for (const QString &str : urlList) {
+        if (str.contains(QLatin1Char('@')))
+            urls += QUrl(str + QLatin1Char('@'));
+        else
+            urls += QUrl(str);
     }
 
     return getActionMenu(urls, true);
@@ -88,8 +91,11 @@ QStringList kdesvnd::getActionMenu(const QStringList &urlList) const
     // we get correct urls here
     QList<QUrl> urls;
     urls.reserve(urlList.size());
-    Q_FOREACH(const QString &str, urlList) {
-        urls += QUrl(str);
+    for (const QString &str : urlList) {
+        if (str.contains(QLatin1Char('@')))
+            urls += QUrl(str + QLatin1Char('@'));
+        else
+            urls += QUrl(str);
     }
     return getActionMenu(urls, false);
 }
@@ -116,52 +122,52 @@ QStringList kdesvnd::getActionMenu(const QList<QUrl> &list, bool toplevel) const
 
     if (!itemIsWc) {
         if (itemIsRepository) {
-            result << "Export"
-                   << "Checkout";
+            result << QStringLiteral("Export")
+                   << QStringLiteral("Checkout");
         } else {
-            result << "Exportto"
-                   << "Checkoutto";
+            result << QStringLiteral("Exportto")
+                   << QStringLiteral("Checkoutto");
         }
     } else {
-        result << "Update"
-               << "Commit";
+        result << QStringLiteral("Update")
+               << QStringLiteral("Commit");
     }
 
     if (!parentIsWc && !itemIsWc) {
         if (itemIsRepository) {
-            result << "Log";
+            result << QStringLiteral("Log");
             if (!toplevel) {
-                result << "Info";
+                result << QStringLiteral("Info");
                 const QUrl upUrl = KIO::upUrl(list.at(0));
                 if (isRepository(upUrl)) {
-                    result << "Blame"
-                           << "Rename";
+                    result << QStringLiteral("Blame")
+                           << QStringLiteral("Rename");
                 }
-                result << "Tree";
+                result << QStringLiteral("Tree");
             }
         }
     } else if (!toplevel) {
         if (!itemIsWc) {
-            result << "Add";
+            result << QStringLiteral("Add");
             return result;
         }
 
-        result << "Log"
-               << "Tree"
-               << "Info"
-               << "Diff"
-               << "Rename"
-               << "Revert";
+        result << QStringLiteral("Log")
+               << QStringLiteral("Tree")
+               << QStringLiteral("Info")
+               << QStringLiteral("Diff")
+               << QStringLiteral("Rename")
+               << QStringLiteral("Revert");
 
         const QUrl url = list.at(0);
         QFileInfo f(url.path());
         if (f.isFile()) {
-            result << "Blame";
+            result << QStringLiteral("Blame");
         }
 
         if (f.isDir()) {
-            result << "Addnew";
-            result << "Switch";
+            result << QStringLiteral("Addnew");
+            result << QStringLiteral("Switch");
         }
     }
     return result;
@@ -170,11 +176,11 @@ QStringList kdesvnd::getActionMenu(const QList<QUrl> &list, bool toplevel) const
 QStringList kdesvnd::getSingleActionMenu(const QString &what) const
 {
     QList<QUrl> l;
-    l.append(QUrl(what));
+    l.append(QUrl(what.contains(QLatin1Char('@')) ? what + QLatin1Char('@') : what));
     return getActionMenu(l, false);
 }
 
-QStringList kdesvnd::get_saved_login(const QString &realm, const QString &user)
+QStringList kdesvnd::get_saved_login(const QString &realm, const QString &user) const
 {
     Q_UNUSED(user);
     QString username;
@@ -187,7 +193,7 @@ QStringList kdesvnd::get_saved_login(const QString &realm, const QString &user)
 
 }
 
-QStringList kdesvnd::get_login(const QString &realm, const QString &user)
+QStringList kdesvnd::get_login(const QString &realm, const QString &user) const
 {
     QPointer<AuthDialogImpl> auth(new AuthDialogImpl(realm, user));
     QStringList res;
@@ -195,16 +201,21 @@ QStringList kdesvnd::get_login(const QString &realm, const QString &user)
         res.append(auth->Username());
         res.append(auth->Password());
         if (auth->maySave()) {
-            res.append("true");
+            res.append(QStringLiteral("true"));
         } else {
-            res.append("false");
+            res.append(QStringLiteral("false"));
         }
     }
     delete auth;
     return res;
 }
 
-int kdesvnd::get_sslaccept(const QString &hostname, const QString &fingerprint, const QString &validFrom, const QString &validUntil, const QString &issuerDName, const QString &realm)
+int kdesvnd::get_sslaccept(const QString &hostname,
+                           const QString &fingerprint,
+                           const QString &validFrom,
+                           const QString &validUntil,
+                           const QString &issuerDName,
+                           const QString &realm) const
 {
     bool ok, saveit;
     if (!SslTrustPrompt::sslTrust(
@@ -224,7 +235,7 @@ int kdesvnd::get_sslaccept(const QString &hostname, const QString &fingerprint,
     return 1;
 }
 
-QString kdesvnd::load_sslclientcertpw(const QString &realm)
+QString kdesvnd::load_sslclientcertpw(const QString &realm) const
 {
     QString password;
     if (!PwStorage::self()->getCertPw(realm, password)) {
@@ -233,19 +244,19 @@ QString kdesvnd::load_sslclientcertpw(const QString &realm)
     return password;
 }
 
-QStringList kdesvnd::get_sslclientcertpw(const QString &realm)
+QStringList kdesvnd::get_sslclientcertpw(const QString &realm) const
 {
     QStringList resList;
-    QPointer<KPasswordDialog> dlg(new KPasswordDialog(0, KPasswordDialog::DomainReadOnly | KPasswordDialog::ShowKeepPassword));
+    QPointer<KPasswordDialog> dlg(new KPasswordDialog(nullptr, KPasswordDialog::DomainReadOnly | KPasswordDialog::ShowKeepPassword));
     dlg->setDomain(realm);
-    dlg->setWindowTitle(i18n("Enter password for realm %1", realm));
+    dlg->setWindowTitle(i18nc("@title:window", "Enter Password for Realm %1", realm));
     dlg->setKeepPassword(true);
     if (dlg->exec() == KPasswordDialog::Accepted) {
         resList.append(dlg->password());
         if (dlg->keepPassword()) {
-            resList.append("true");
+            resList.append(QStringLiteral("true"));
         } else {
-            resList.append("false");
+            resList.append(QStringLiteral("false"));
         }
     }
     delete dlg;
@@ -261,7 +272,7 @@ QStringList kdesvnd::get_logmsg() const
 {
     QStringList res;
     bool ok;
-    QString logMessage = Commitmsg_impl::getLogmessage(&ok, 0, 0, 0);
+    QString logMessage = Commitmsg_impl::getLogmessage(&ok, nullptr, nullptr, nullptr);
     if (ok) {
         res.append(logMessage);
     }
@@ -270,7 +281,7 @@ QStringList kdesvnd::get_logmsg() const
 
 QString kdesvnd::cleanUrl(const QUrl &url)
 {
-    return url.adjusted(QUrl::StripTrailingSlash).path();
+    return url.adjusted(QUrl::StripTrailingSlash|QUrl::NormalizePathSegments).path();
 }
 
 /* just simple name check of course - no network access! */
@@ -293,7 +304,7 @@ bool kdesvnd::isRepository(const QUrl &url) const
 
 bool kdesvnd::isWorkingCopy(const QUrl &url) const
 {
-    if (url.isEmpty() || !url.isLocalFile() || url.scheme() != QLatin1String("file")) {
+    if (url.isEmpty() || !url.isLocalFile() || url.scheme() != QLatin1String("file") || url.path() == QLatin1String("/")) {
         return false;
     }
     svn::Revision peg(svn_opt_revision_unspecified);
@@ -331,7 +342,7 @@ void kdesvnd::registerKioFeedback(qulonglong kioid)
                                                                qApp->applicationName(),
                                                                0x0003);
     if (reply.isValid()) {
-        KsvnJobView *jobView = new KsvnJobView(kioid, "org.kde.JobViewServer",
+        KsvnJobView *jobView = new KsvnJobView(kioid, QStringLiteral("org.kde.JobViewServer"),
                                                reply.value().path(),
                                                QDBusConnection::sessionBus());
         progressJobView.insert(kioid, jobView);
@@ -352,7 +363,7 @@ void kdesvnd::transferredKioOperation(qulonglong kioid, qulonglong transferred)
 {
     CHECK_KIO;
     if (progressJobView[kioid]->max() > -1) {
-        progressJobView[kioid]->setProcessedAmount(transferred, "bytes");
+        progressJobView[kioid]->setProcessedAmount(transferred, QStringLiteral("bytes"));
         progressJobView[kioid]->setPercent(progressJobView[kioid]->percent(transferred));
         progressJobView[kioid]->clearDescriptionField(1);
     } else {
@@ -373,7 +384,7 @@ void kdesvnd::notifyKioOperation(const QString &text)
 {
     KNotification::event(
         QLatin1String("kdesvn-kio"), text,
-        QPixmap(), 0L, KNotification::CloseOnTimeout,
+        QPixmap(), nullptr, KNotification::CloseOnTimeout,
         QLatin1String("kdesvn"));
 }
 
@@ -381,7 +392,7 @@ void kdesvnd::errorKioOperation(const QString &text)
 {
     KNotification::event(
         KNotification::Error, text,
-        QPixmap(), 0L, KNotification::CloseOnTimeout
+        QPixmap(), nullptr, KNotification::CloseOnTimeout
     );
 }
 
