@@ -69,29 +69,30 @@ kdesvnView::kdesvnView(KActionCollection *aCollection, QWidget *parent, bool ful
     m_infoSplitter->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding);
     m_LogWindow = new QTextBrowser(m_infoSplitter);
     m_LogWindow->setContextMenuPolicy(Qt::CustomContextMenu);
-    connect(m_LogWindow, SIGNAL(customContextMenuRequested(QPoint)),
-            this, SLOT(onCustomLogWindowContextMenuRequested(QPoint)));
+    connect(m_LogWindow, &QWidget::customContextMenuRequested,
+            this, &kdesvnView::onCustomLogWindowContextMenuRequested);
     Propertylist *pl = new Propertylist(m_infoSplitter);
     pl->setCommitchanges(true);
-    pl->addCallback(m_TreeWidget);
-    connect(m_TreeWidget, SIGNAL(sigProplist(svn::PathPropertiesMapListPtr,bool,bool,QString)),
-            pl, SLOT(displayList(svn::PathPropertiesMapListPtr,bool,bool,QString)));
-    connect(m_TreeWidget, SIGNAL(sigProplist(svn::PathPropertiesMapListPtr,bool,bool,QString)),
-            pl, SLOT(displayList(svn::PathPropertiesMapListPtr,bool,bool,QString)));
+    connect(pl, &Propertylist::sigSetProperty,
+            m_TreeWidget, &MainTreeWidget::slotChangeProperties);
+    connect(m_TreeWidget, &MainTreeWidget::sigProplist,
+            pl, &Propertylist::displayList);
+    connect(m_TreeWidget, &MainTreeWidget::sigProplist,
+            pl, &Propertylist::displayList);
 
     m_TreeWidget->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding);
 
     m_topLayout->addWidget(m_Splitter);
-    connect(m_TreeWidget, SIGNAL(sigLogMessage(QString)), this, SLOT(slotAppendLog(QString)));
-    connect(m_TreeWidget, SIGNAL(changeCaption(QString)), this, SLOT(slotSetTitle(QString)));
-    connect(m_TreeWidget, SIGNAL(sigShowPopup(QString,QWidget**)), this, SLOT(slotDispPopup(QString,QWidget**)));
-    connect(m_TreeWidget, SIGNAL(sigUrlOpend(bool)), parent, SLOT(slotUrlOpened(bool)));
-    connect(m_TreeWidget, SIGNAL(sigSwitchUrl(QUrl)), this, SIGNAL(sigSwitchUrl(QUrl)));
+    connect(m_TreeWidget, &MainTreeWidget::sigLogMessage, this, &kdesvnView::slotAppendLog);
+    connect(m_TreeWidget, &MainTreeWidget::changeCaption, this, &kdesvnView::slotSetTitle);
+    connect(m_TreeWidget, &MainTreeWidget::sigShowPopup, this, &kdesvnView::slotDispPopup);
+    connect(m_TreeWidget, &MainTreeWidget::sigUrlOpened, this, &kdesvnView::sigUrlOpened);
+    connect(m_TreeWidget, &MainTreeWidget::sigSwitchUrl, this, &kdesvnView::sigSwitchUrl);
     connect(m_TreeWidget, &MainTreeWidget::sigUrlChanged, this, &kdesvnView::slotUrlChanged);
-    connect(m_TreeWidget, SIGNAL(sigCacheStatus(qlonglong,qlonglong)), this, SLOT(fillCacheStatus(qlonglong,qlonglong)));
-    connect(m_TreeWidget, SIGNAL(sigExtraStatusMessage(QString)), this, SIGNAL(sigExtraStatusMessage(QString)));
+    connect(m_TreeWidget, &MainTreeWidget::sigCacheStatus, this, &kdesvnView::fillCacheStatus);
+    connect(m_TreeWidget, &MainTreeWidget::sigExtraStatusMessage, this, &kdesvnView::sigExtraStatusMessage);
 
-    connect(this, SIGNAL(sigMakeBaseDirs()), m_TreeWidget, SLOT(slotMkBaseDirs()));
+    connect(this, &kdesvnView::sigMakeBaseDirs, m_TreeWidget, &MainTreeWidget::slotMkBaseDirs);
 
     KConfigGroup cs(Kdesvnsettings::self()->config(), "kdesvn-mainlayout");
     QByteArray t1 = cs.readEntry("split1", QByteArray());
@@ -254,7 +255,7 @@ void kdesvnView::slotCreateRepo()
 void kdesvnView::slotHotcopy()
 {
     QPointer<KSvnSimpleOkDialog> dlg(new KSvnSimpleOkDialog(QStringLiteral("hotcopy_repo_size"), QApplication::activeModalWidget()));
-    dlg->setWindowTitle(i18n("Hotcopy a repository"));
+    dlg->setWindowTitle(i18nc("@title:window", "Hotcopy a Repository"));
     dlg->setWithCancelButton();
 
     HotcopyDlg_impl *ptr = new HotcopyDlg_impl(dlg);
@@ -281,7 +282,7 @@ void kdesvnView::slotHotcopy()
 void kdesvnView::slotLoaddump()
 {
     QPointer<KSvnSimpleOkDialog> dlg(new KSvnSimpleOkDialog(QStringLiteral("loaddump_repo_size"), this));
-    dlg->setWindowTitle(i18n("Load a repository from a svndump"));
+    dlg->setWindowTitle(i18nc("@title:window", "Load a Repository From an svndump"));
     dlg->setWithCancelButton();
 
     LoadDmpDlg_impl *ptr(new LoadDmpDlg_impl(dlg));
@@ -331,7 +332,7 @@ void kdesvnView::slotLoaddump()
     }
 
     try {
-        StopDlg sdlg(this, this, i18n("Load Dump"), i18n("Loading a dump into a repository."));
+        StopDlg sdlg(nullptr, this, i18nc("@title:window", "Load Dump"), i18n("Loading a dump into a repository."));
         _rep.loaddump(_input, _act, ptr->parentPath(), ptr->usePre(), ptr->usePost(), ptr->validateProps());
         slotAppendLog(i18n("Loading dump finished."));
     } catch (const svn::ClientException &e) {
@@ -343,7 +344,7 @@ void kdesvnView::slotLoaddump()
 void kdesvnView::slotDumpRepo()
 {
     QPointer<KSvnSimpleOkDialog> dlg(new KSvnSimpleOkDialog(QStringLiteral("dump_repo_size"), QApplication::activeModalWidget()));
-    dlg->setWindowTitle(i18n("Dump a repository"));
+    dlg->setWindowTitle(i18nc("@title:window", "Dump a Repository"));
     dlg->setWithCancelButton();
 
     DumpRepo_impl *ptr(new DumpRepo_impl(dlg));
@@ -383,7 +384,7 @@ void kdesvnView::slotDumpRepo()
     }
 
     try {
-        StopDlg sdlg(this, this, i18n("Dump"), i18n("Dumping a repository"));
+        StopDlg sdlg(nullptr, this, i18nc("@title:window", "Dump"), i18n("Dumping a repository"));
         _rep->dump(out, st, en, incr, diffs);
         slotAppendLog(i18n("Dump finished."));
     } catch (const svn::ClientException &e) {
@@ -438,7 +439,7 @@ void kdesvnView::fillCacheStatus(qlonglong current, qlonglong max)
         m_CacheProgressBar->setValue((int)current);
     } else {
         delete m_CacheProgressBar;
-        m_CacheProgressBar = 0;
+        m_CacheProgressBar = nullptr;
     }
 }
 
@@ -452,8 +453,8 @@ void kdesvnView::onCustomLogWindowContextMenuRequested(const QPoint &pos)
     QPointer<QMenu> menu = m_LogWindow->createStandardContextMenu();
     QAction *clearAction = new QAction(tr("Clear"), menu.data());
     clearAction->setEnabled(!m_LogWindow->toPlainText().isEmpty());
-    connect(clearAction, SIGNAL(triggered(bool)),
-            m_LogWindow, SLOT(clear()));
+    connect(clearAction, &QAction::triggered,
+            m_LogWindow, &QTextEdit::clear);
     menu->addAction(clearAction);
     menu->exec(m_LogWindow->mapToGlobal(pos));
     delete menu;
