@@ -48,6 +48,7 @@
 #include <netinet/in.h>
 #include <netdb.h>
 #include <klocalizedstring.h>
+#include <kio_version.h>
 
 namespace KIO
 {
@@ -111,7 +112,7 @@ KioSvnData::~KioSvnData()
     m_Listener.setCancel(true);
     /* wait a little bit */
     sleep(1);
-    m_CurrentContext->setListener(0L);
+    m_CurrentContext->setListener(nullptr);
 }
 
 svn::Revision KioSvnData::urlToRev(const QUrl &url)
@@ -128,7 +129,7 @@ svn::Revision KioSvnData::urlToRev(const QUrl &url)
 
     svn::Revision rev = svn::Revision::UNDEFINED;
     typedef QPair<QString, QString> myStrPair;
-    Q_FOREACH(const myStrPair &p, q) {
+    for (const myStrPair &p : q) {
         if (p.first == QLatin1String("rev")) {
             const QString v = p.second;
             svn::Revision tmp;
@@ -184,14 +185,11 @@ void kio_svnProtocol::listSendDirEntry(const svn::DirEntry &direntry)
         qCDebug(KDESVN_LOG) << "Skipping empty entry!" << endl;
         return;
     }
-    if (createUDSEntry(direntry.name(),
-                       direntry.lastAuthor(),
-                       direntry.size(),
-                       direntry.kind() == svn_node_dir ? true : false,
-                       dt.toTime_t(),
-                       entry)) {
-        listEntry(entry);
-    }
+    listEntry(createUDSEntry(direntry.name(),
+                             direntry.lastAuthor(),
+                             direntry.size(),
+                             direntry.kind() == svn_node_dir ? true : false,
+                             dt));
 }
 
 /*!
@@ -209,7 +207,7 @@ void kio_svnProtocol::listDir(const QUrl &url)
 
     try {
         // we ignoring the result 'cause it is done via kiolistener for a smoother insert of items.
-        dlist = m_pData->m_Svnclient->list(makeSvnUrl(url), rev, rev, svn::DepthImmediates, false);
+        dlist = m_pData->m_Svnclient->list(makeSvnPath(url), rev, rev, svn::DepthImmediates, false);
     } catch (const svn::ClientException &e) {
         QString ex = e.msg();
         qCDebug(KDESVN_LOG) << ex << endl;
@@ -232,7 +230,7 @@ void kio_svnProtocol::stat(const QUrl &url)
     bool dummy = false;
     svn::InfoEntries e;
     try {
-        e = m_pData->m_Svnclient->info(makeSvnUrl(url), svn::DepthEmpty, rev, peg);
+        e = m_pData->m_Svnclient->info(makeSvnPath(url), svn::DepthEmpty, rev, peg);
     } catch (const svn::ClientException &e) {
         QString ex = e.msg();
         qCDebug(KDESVN_LOG) << ex << endl;
@@ -246,13 +244,13 @@ void kio_svnProtocol::stat(const QUrl &url)
 
     KIO::UDSEntry entry;
     if (dummy) {
-        createUDSEntry(url.fileName(), QString(), 0, true, 0, entry);
+        entry = createUDSEntry(url.fileName(), QString(), 0, true, QDateTime());
     } else {
         const QDateTime dt(e[0].cmtDate().toQDateTime());
         if (e[0].kind() == svn_node_file) {
-            createUDSEntry(url.fileName(), QString(), 0, false, dt.toTime_t(), entry);
+            entry = createUDSEntry(url.fileName(), QString(), 0, false, dt);
         } else {
-            createUDSEntry(url.fileName(), QString(), 0, true, dt.toTime_t(), entry);
+            entry = createUDSEntry(url.fileName(), QString(), 0, true, dt);
         }
     }
     statEntry(entry);
@@ -271,19 +269,19 @@ void kio_svnProtocol::get(const QUrl &url)
     }
     KioByteStream dstream(this, url.fileName());
     try {
-        QUrl _url = makeSvnUrl(url);
+        const svn::Path path = makeSvnPath(url);
         svn::InfoEntries e;
-        e = m_pData->m_Svnclient->info(_url, svn::DepthEmpty, rev, rev);
+        e = m_pData->m_Svnclient->info(path, svn::DepthEmpty, rev, rev);
         if (!e.isEmpty()) {
             totalSize(e.at(0).size());
         }
-        m_pData->m_Svnclient->cat(dstream, _url, rev, rev);
+        m_pData->m_Svnclient->cat(dstream, path, rev, rev);
     } catch (const svn::ClientException &e) {
         QString ex = e.msg();
         // dolphin / Konqueror try to get the content without check if it is a folder when listing a folder
         // which results in a lot of error messages via kio notify
         if (e.apr_err() != SVN_ERR_CLIENT_IS_DIRECTORY) {
-            extraError(KIO::ERR_SLAVE_DEFINED, "Subversion error " + ex);
+            extraError(KIO::ERR_SLAVE_DEFINED, QStringLiteral("Subversion error ") + ex);
         }
         return;
     }
@@ -305,8 +303,7 @@ void kio_svnProtocol::mkdir(const QUrl &url, int)
     }
     m_pData->m_CurrentContext->setLogMessage(getDefaultLog());
     try {
-        svn::Path p(makeSvnUrl(url));
-        m_pData->m_Svnclient->mkdir(p, getDefaultLog());
+        m_pData->m_Svnclient->mkdir(makeSvnPath(url), getDefaultLog());
     } catch (const svn::ClientException &e) {
         extraError(KIO::ERR_SLAVE_DEFINED, e.msg());
         return;
@@ -317,7 +314,7 @@ void kio_svnProtocol::mkdir(const QUrl &url, int)
 void kio_svnProtocol::mkdir(const QList<QUrl> &urls, int)
 {
     try {
-        m_pData->m_Svnclient->mkdir(svn::Targets::fromUrlList(urls), getDefaultLog());
+        m_pData->m_Svnclient->mkdir(svn::Targets::fromUrlList(urls, svn::Targets::UrlConversion::PreferLocalPath), getDefaultLog());
     } catch (const svn::ClientException &e) {
         extraError(KIO::ERR_SLAVE_DEFINED, e.msg());
         return;
@@ -333,7 +330,7 @@ void kio_svnProtocol::rename(const QUrl &src, const QUrl &target, KIO::JobFlags
     //bool force  = flags&KIO::Overwrite;
     m_pData->m_CurrentContext->setLogMessage(getDefaultLog());
     try {
-        m_pData->m_Svnclient->move(svn::CopyParameter(svn::Path(makeSvnUrl(src)), makeSvnUrl(target)));
+        m_pData->m_Svnclient->move(svn::CopyParameter(makeSvnPath(src), makeSvnPath(target)));
     } catch (const svn::ClientException &e) {
         if (e.apr_err() == SVN_ERR_ENTRY_EXISTS) {
             error(KIO::ERR_DIR_ALREADY_EXIST, e.msg());
@@ -342,7 +339,7 @@ void kio_svnProtocol::rename(const QUrl &src, const QUrl &target, KIO::JobFlags
         }
         return;
     }
-    notify(i18n("Renaming %1 to %2 succesfull", src.toDisplayString(), target.toDisplayString()));
+    notify(i18n("Renaming %1 to %2 successful", src.toDisplayString(), target.toDisplayString()));
     finished();
 }
 
@@ -362,7 +359,7 @@ void kio_svnProtocol::put(const QUrl &url, int permissions, KIO::JobFlags flags)
     svn::InfoEntries e;
     bool exists = true;
     try {
-        e = m_pData->m_Svnclient->info(makeSvnUrl(url), svn::DepthEmpty, rev, peg);
+        e = m_pData->m_Svnclient->info(makeSvnPath(url), svn::DepthEmpty, rev, peg);
     } catch (const svn::ClientException &e) {
         if (e.apr_err() == SVN_ERR_ENTRY_NOT_FOUND || e.apr_err() == SVN_ERR_RA_ILLEGAL_URL) {
             exists = false;
@@ -381,7 +378,7 @@ void kio_svnProtocol::put(const QUrl &url, int permissions, KIO::JobFlags flags)
             }
             _codir = QSharedPointer<QTemporaryDir>(new QTemporaryDir);
             _codir->setAutoRemove(true);
-            svn::Path path = makeSvnUrl(url);
+            svn::Path path = makeSvnPath(url);
             path.removeLast();
             try {
                 notify(i18n("Start checking out to temporary folder"));
@@ -438,7 +435,7 @@ void kio_svnProtocol::put(const QUrl &url, int permissions, KIO::JobFlags flags)
     written(0);
     m_pData->dispWritten = true;
     registerToDaemon();
-    startOp(processed_size, i18n("Committing %1", makeSvnUrl(url).toDisplayString()));
+    startOp(processed_size, i18n("Committing %1", makeSvnPath(url).path()));
     bool err = false;
     if (exists) {
         svn::CommitParameter commit_parameters;
@@ -451,7 +448,7 @@ void kio_svnProtocol::put(const QUrl &url, int permissions, KIO::JobFlags flags)
         }
     } else  {
         try {
-            m_pData->m_Svnclient->import(tmpfile->fileName(), svn::Url(makeSvnUrl(url)), getDefaultLog(), svn::DepthEmpty, false, false);
+            m_pData->m_Svnclient->import(tmpfile->fileName(), svn::Url(makeSvnPath(url)), getDefaultLog(), svn::DepthEmpty, false, false);
         } catch (const svn::ClientException &e) {
             QString ex = e.msg();
             extraError(KIO::ERR_SLAVE_DEFINED, e.msg());
@@ -480,7 +477,7 @@ void kio_svnProtocol::copy(const QUrl &src, const QUrl &dest, int permissions, K
     m_pData->dispProgress = true;
     m_pData->m_CurrentContext->setLogMessage(getDefaultLog());
     try {
-        m_pData->m_Svnclient->copy(makeSvnUrl(src), rev, makeSvnUrl(dest));
+        m_pData->m_Svnclient->copy(makeSvnPath(src), rev, makeSvnPath(dest));
     } catch (const svn::ClientException &e) {
         if (e.apr_err() == SVN_ERR_ENTRY_EXISTS) {
             error(KIO::ERR_DIR_ALREADY_EXIST, e.msg());
@@ -492,7 +489,7 @@ void kio_svnProtocol::copy(const QUrl &src, const QUrl &dest, int permissions, K
     }
     m_pData->dispProgress = false;
     qCDebug(KDESVN_LOG) << "kio_svn::copy finished" <<  endl;
-    notify(i18n("Copied %1 to %2", makeSvnUrl(src).toDisplayString(), makeSvnUrl(dest).toDisplayString()));
+    notify(i18n("Copied %1 to %2", makeSvnPath(src).path(), makeSvnPath(dest).path()));
     finished();
 }
 
@@ -512,7 +509,7 @@ void kio_svnProtocol::del(const QUrl &src, bool isfile)
     }
     m_pData->m_CurrentContext->setLogMessage(getDefaultLog());
     try {
-        svn::Targets target(makeSvnUrl(src));
+        svn::Targets target(makeSvnPath(src));
         m_pData->m_Svnclient->remove(target, false);
     } catch (const svn::ClientException &e) {
         extraError(KIO::ERR_SLAVE_DEFINED, e.msg());
@@ -529,17 +526,17 @@ bool kio_svnProtocol::getLogMsg(QString &t)
     return m_pData->m_Listener.contextGetLogMessage(t, _items);
 }
 
-bool kio_svnProtocol::checkWc(const QUrl &url) const
+bool kio_svnProtocol::checkWc(const svn::Path &localPath) const
 {
     m_pData->resetListener();
-    if (url.isEmpty() || !url.isLocalFile()) {
+    if (!localPath.isSet()) {
         return false;
     }
     svn::Revision peg(svn_opt_revision_unspecified);
     svn::Revision rev(svn_opt_revision_unspecified);
     svn::InfoEntries e;
     try {
-        e = m_pData->m_Svnclient->info(svn::Path(url), svn::DepthEmpty, rev, peg);
+        e = m_pData->m_Svnclient->info(localPath, svn::DepthEmpty, rev, peg);
     } catch (const svn::ClientException &e) {
         if (SVN_ERR_WC_NOT_DIRECTORY == e.apr_err()) {
             return false;
@@ -549,31 +546,43 @@ bool kio_svnProtocol::checkWc(const QUrl &url) const
     return false;
 }
 
-QUrl kio_svnProtocol::makeSvnUrl(const QUrl &url, bool check_Wc) const
+svn::Path kio_svnProtocol::makeSvnPath(const QUrl &url) const
 {
     const QString scheme = svn::Url::transformProtokoll(url.scheme());
-    if (scheme == QLatin1String("file") && check_Wc) {
-        if (checkWc(url)) {
-            return url;
+    if (scheme == QLatin1String("file")) {
+        const svn::Path path(url.toLocalFile());
+        if (checkWc(path)) {
+            return path;
         }
     }
-    QUrl tmpUrl(url);
-    tmpUrl.setScheme(scheme);
-
     if (url.path().isEmpty()) {
         throw svn::ClientException(QLatin1Char('\'') + url.url() + QLatin1String("' is not a valid subversion url"));
     }
-    return tmpUrl;
+
+    QUrl tmpUrl(url);
+    tmpUrl.setScheme(scheme);
+    tmpUrl.setQuery(QString()); // svn doesn't know anything about queries (e.g ?rev=X)
+
+    return svn::Path(tmpUrl.toString(QUrl::NormalizePathSegments));
 }
 
-bool kio_svnProtocol::createUDSEntry(const QString &filename, const QString &user, long long int size, bool isdir, time_t mtime, KIO::UDSEntry &entry)
+KIO::UDSEntry kio_svnProtocol::createUDSEntry(const QString &filename, const QString &user, long long int size, bool isdir, const QDateTime &mtime)
 {
+    KIO::UDSEntry entry;
+#if KIO_VERSION <= QT_VERSION_CHECK(5, 48, 0)
     entry.insert(KIO::UDSEntry::UDS_NAME, filename);
     entry.insert(KIO::UDSEntry::UDS_FILE_TYPE, isdir ? S_IFDIR : S_IFREG);
     entry.insert(KIO::UDSEntry::UDS_SIZE, size);
-    entry.insert(KIO::UDSEntry::UDS_MODIFICATION_TIME, mtime);
+    entry.insert(KIO::UDSEntry::UDS_MODIFICATION_TIME, mtime.toSecsSinceEpoch());
     entry.insert(KIO::UDSEntry::UDS_USER, user);
-    return true;
+#else
+    entry.fastInsert(KIO::UDSEntry::UDS_NAME, filename);
+    entry.fastInsert(KIO::UDSEntry::UDS_FILE_TYPE, isdir ? S_IFDIR : S_IFREG);
+    entry.fastInsert(KIO::UDSEntry::UDS_SIZE, size);
+    entry.fastInsert(KIO::UDSEntry::UDS_MODIFICATION_TIME, mtime.toSecsSinceEpoch());
+    entry.fastInsert(KIO::UDSEntry::UDS_USER, user);
+#endif
+    return entry;
 }
 
 void kio_svnProtocol::special(const QByteArray &data)
@@ -767,11 +776,11 @@ void kio_svnProtocol::status(const QUrl &wc, bool cR, bool rec)
         return;
     }
     qCDebug(KDESVN_LOG) << "Status got " << dlist.count() << " entries." << endl;
-    Q_FOREACH (const svn::StatusPtr &s, dlist) {
+    for (const svn::StatusPtr &s : qAsConst(dlist)) {
         if (!s) {
             continue;
         }
-        const QString cntStr(QString::number(m_pData->m_Listener.counter()).rightJustified(10, '0'));
+        const QString cntStr(QString::number(m_pData->m_Listener.counter()).rightJustified(10, QLatin1Char('0')));
         //QDataStream stream(params, QIODevice::WriteOnly);
         setMetaData(cntStr + QLatin1String("path"), s->path());
         setMetaData(cntStr + QLatin1String("node"), QString::number(s->nodeStatus()));
@@ -799,14 +808,14 @@ void kio_svnProtocol::commit(const QList<QUrl> &urls)
     QStringList lt = res;
 
     if (lt.count() != 1) {
-        msg = "Wrong or missing log (may cancel pressed).";
+        msg = i18n("Wrong or missing log (may cancel pressed).");
         qCDebug(KDESVN_LOG) << msg << endl;
         return;
     }
     msg = lt[0];
     svn::Revision nnum = svn::Revision::UNDEFINED;
     svn::CommitParameter commit_parameters;
-    commit_parameters.targets(svn::Targets::fromUrlList(urls)).message(msg).depth(svn::DepthInfinity).keepLocks(false);
+    commit_parameters.targets(svn::Targets::fromUrlList(urls, svn::Targets::UrlConversion::PreferLocalPath)).message(msg).depth(svn::DepthInfinity).keepLocks(false);
 
     try {
         nnum = m_pData->m_Svnclient->commit(commit_parameters);
@@ -820,14 +829,16 @@ void kio_svnProtocol::commit(const QList<QUrl> &urls)
         } else {
             userstring = i18n("Nothing to commit.");
         }
-        setMetaData(QString::number(m_pData->m_Listener.counter()).rightJustified(10, '0') + "path", urls[j].path());
-        setMetaData(QString::number(m_pData->m_Listener.counter()).rightJustified(10, '0') + "action", "0");
-        setMetaData(QString::number(m_pData->m_Listener.counter()).rightJustified(10, '0') + "kind", "0");
-        setMetaData(QString::number(m_pData->m_Listener.counter()).rightJustified(10, '0') + "mime_t", "");
-        setMetaData(QString::number(m_pData->m_Listener.counter()).rightJustified(10, '0') + "content", "0");
-        setMetaData(QString::number(m_pData->m_Listener.counter()).rightJustified(10, '0') + "prop", "0");
-        setMetaData(QString::number(m_pData->m_Listener.counter()).rightJustified(10, '0') + "rev" , QString::number(nnum));
-        setMetaData(QString::number(m_pData->m_Listener.counter()).rightJustified(10, '0') + "string", userstring);
+        const QString num(QString::number(m_pData->m_Listener.counter()).rightJustified(10, QLatin1Char('0')));
+        const QString zero(QStringLiteral("0"));
+        setMetaData(num + QLatin1String("path"), urls[j].path());
+        setMetaData(num + QLatin1String("action"), zero);
+        setMetaData(num + QLatin1String("kind"), zero);
+        setMetaData(num + QLatin1String("mime_t"), QString());
+        setMetaData(num + QLatin1String("content"), zero);
+        setMetaData(num + QLatin1String("prop"), zero);
+        setMetaData(num + QLatin1String("rev") , QString::number(nnum));
+        setMetaData(num + QLatin1String("string"), userstring);
         m_pData->m_Listener.incCounter();
     }
 }
@@ -837,7 +848,7 @@ void kio_svnProtocol::checkout(const QUrl &src, const QUrl &target, const int re
     svn::Revision where(rev, revstring);
     try {
         svn::CheckoutParameter params;
-        params.moduleName(makeSvnUrl(src)).destination(target.path()).revision(where).peg(svn::Revision::UNDEFINED).depth(svn::DepthInfinity);
+        params.moduleName(makeSvnPath(src)).destination(target.path()).revision(where).peg(svn::Revision::UNDEFINED).depth(svn::DepthInfinity);
         m_pData->m_Svnclient->checkout(params);
     } catch (const svn::ClientException &e) {
         extraError(KIO::ERR_SLAVE_DEFINED, e.msg());
@@ -854,14 +865,15 @@ void kio_svnProtocol::svnlog(int revstart, const QString &revstringstart, int re
     for (long j = 0; j < urls.count(); ++j) {
         svn::LogEntriesMap logs;
         try {
-            m_pData->m_Svnclient->log(params.targets(svn::Path(makeSvnUrl(urls[j]))), logs);
+            m_pData->m_Svnclient->log(params.targets(makeSvnPath(urls[j])), logs);
         } catch (const svn::ClientException &e) {
             extraError(KIO::ERR_SLAVE_DEFINED, e.msg());
             break;
         }
         if (logs.isEmpty()) {
-            setMetaData(QString::number(m_pData->m_Listener.counter()).rightJustified(10, '0') + "path", urls[j].path());
-            setMetaData(QString::number(m_pData->m_Listener.counter()).rightJustified(10, '0') + "string",
+            const QString num(QString::number(m_pData->m_Listener.counter()).rightJustified(10, QLatin1Char('0')));
+            setMetaData(num + QStringLiteral("path"), urls[j].path());
+            setMetaData(num + QStringLiteral("string"),
                         i18n("Empty logs"));
             m_pData->m_Listener.incCounter();
             continue;
@@ -869,26 +881,20 @@ void kio_svnProtocol::svnlog(int revstart, const QString &revstringstart, int re
 
         svn::LogEntriesMap::const_iterator it = logs.constBegin();
         for (; it != logs.constEnd(); ++it) {
-            setMetaData(QString::number(m_pData->m_Listener.counter()).rightJustified(10, '0') + "path", urls[j].path());
-            setMetaData(QString::number(m_pData->m_Listener.counter()).rightJustified(10, '0') + "rev",
-                        QString::number((*it).revision));
-            setMetaData(QString::number(m_pData->m_Listener.counter()).rightJustified(10, '0') + "author",
-                        (*it).author);
-            setMetaData(QString::number(m_pData->m_Listener.counter()).rightJustified(10, '0') + "logmessage",
-                        (*it).message);
+            const QString num(QString::number(m_pData->m_Listener.counter()).rightJustified(10, QLatin1Char('0')));
+            setMetaData(num + QStringLiteral("path"), urls[j].path());
+            setMetaData(num + QStringLiteral("rev"), QString::number((*it).revision));
+            setMetaData(num + QStringLiteral("author"), (*it).author);
+            setMetaData(num + QStringLiteral("logmessage"), (*it).message);
             m_pData->m_Listener.incCounter();
             for (long z = 0; z < (*it).changedPaths.count(); ++z) {
-                setMetaData(QString::number(m_pData->m_Listener.counter()).rightJustified(10, '0') + "rev",
-                            QString::number((*it).revision));
-                setMetaData(QString::number(m_pData->m_Listener.counter()).rightJustified(10, '0') + "path", urls[j].path());
-                setMetaData(QString::number(m_pData->m_Listener.counter()).rightJustified(10, '0') + "loggedpath",
-                            (*it).changedPaths[z].path);
-                setMetaData(QString::number(m_pData->m_Listener.counter()).rightJustified(10, '0') + "loggedaction",
-                            QChar((*it).changedPaths[z].action));
-                setMetaData(QString::number(m_pData->m_Listener.counter()).rightJustified(10, '0') + "loggedcopyfrompath",
-                            (*it).changedPaths[z].copyFromPath);
-                setMetaData(QString::number(m_pData->m_Listener.counter()).rightJustified(10, '0') + "loggedcopyfromrevision",
-                            QString::number((*it).changedPaths[z].copyFromRevision));
+                const QString num(QString::number(m_pData->m_Listener.counter()).rightJustified(10, QLatin1Char('0')));
+                setMetaData(num + QStringLiteral("rev"), QString::number((*it).revision));
+                setMetaData(num + QStringLiteral("path"), urls[j].path());
+                setMetaData(num + QStringLiteral("loggedpath"), (*it).changedPaths[z].path);
+                setMetaData(num + QStringLiteral("loggedaction"), QString(QLatin1Char((*it).changedPaths[z].action)));
+                setMetaData(num + QStringLiteral("loggedcopyfrompath"), (*it).changedPaths[z].copyFromPath);
+                setMetaData(num + QStringLiteral("loggedcopyfromrevision"), QString::number((*it).changedPaths[z].copyFromRevision));
                 m_pData->m_Listener.incCounter();
 
             }
@@ -899,7 +905,7 @@ void kio_svnProtocol::svnlog(int revstart, const QString &revstringstart, int re
 void kio_svnProtocol::revert(const QList<QUrl> &urls)
 {
     try {
-        m_pData->m_Svnclient->revert(svn::Targets::fromUrlList(urls), svn::DepthEmpty);
+        m_pData->m_Svnclient->revert(svn::Targets::fromUrlList(urls, svn::Targets::UrlConversion::PreferLocalPath), svn::DepthEmpty);
     } catch (const svn::ClientException &e) {
         extraError(KIO::ERR_SLAVE_DEFINED, e.msg());
     }
@@ -910,7 +916,7 @@ void kio_svnProtocol::wc_switch(const QUrl &wc, const QUrl &target, bool rec, in
     svn::Revision where(rev, revstring);
     svn::Path wc_path(wc.path());
     try {
-        m_pData->m_Svnclient->doSwitch(wc_path, svn::Url(makeSvnUrl(target)), where, rec ? svn::DepthInfinity : svn::DepthFiles);
+        m_pData->m_Svnclient->doSwitch(wc_path, svn::Url(makeSvnPath(target)), where, rec ? svn::DepthInfinity : svn::DepthFiles);
     } catch (const svn::ClientException &e) {
         extraError(KIO::ERR_SLAVE_DEFINED, e.msg());
     }
@@ -923,18 +929,18 @@ void kio_svnProtocol::diff(const QUrl &uri1, const QUrl &uri2, int rnum1, const
     try {
         const svn::Revision r1(rnum1, rstring1);
         const svn::Revision r2(rnum2, rstring2);
-        const QUrl u1 = makeSvnUrl(uri1, true);
-        const QUrl u2 = makeSvnUrl(uri2, true);
+        const svn::Path u1 = makeSvnPath(uri1);
+        const svn::Path u2 = makeSvnPath(uri2);
         QTemporaryDir tdir;
-        qCDebug(KDESVN_LOG) << "kio_ksvn::diff : " << u1 << " at revision " << r1.toString() << " with "
-                     << u2 << " at revision " << r2.toString()
-                     << endl ;
+        qCDebug(KDESVN_LOG) << "kio_ksvn::diff : " << u1.path() << " at revision " << r1.toString() << " with "
+                            << u2.path() << " at revision " << r2.toString()
+                            << endl ;
         svn::DiffParameter _opts;
         // no peg revision required
         _opts.path1(u1).path2(u2).tmpPath(tdir.path()).
         rev1(r1).rev2(r2).
         ignoreContentType(false).extra(svn::StringArray()).depth(rec ? svn::DepthInfinity : svn::DepthEmpty).ignoreAncestry(false).noDiffDeleted(false).
-        relativeTo(svn::Path((u1 == u2 ? u1 : QUrl()))).changeList(svn::StringArray());
+        relativeTo((u1.path() == u2.path() ? u1 : svn::Path())).changeList(svn::StringArray());
 
         tdir.setAutoRemove(true);
         ex = m_pData->m_Svnclient->diff(_opts);
@@ -943,9 +949,10 @@ void kio_svnProtocol::diff(const QUrl &uri1, const QUrl &uri2, int rnum1, const
         return;
     }
     QString out = QString::fromUtf8(ex);
+    const QString num(QString::number(m_pData->m_Listener.counter()).rightJustified(10, QLatin1Char('0')));
     QTextStream stream(&out);
     while (!stream.atEnd()) {
-        setMetaData(QString::number(m_pData->m_Listener.counter()).rightJustified(10, '0') + "diffresult", stream.readLine());
+        setMetaData(num + QStringLiteral("diffresult"), stream.readLine());
         m_pData->m_Listener.incCounter();
     }
 }
@@ -953,9 +960,9 @@ void kio_svnProtocol::diff(const QUrl &uri1, const QUrl &uri2, int rnum1, const
 void kio_svnProtocol::import(const QUrl &repos, const QUrl &wc)
 {
     try {
-        const QUrl target = makeSvnUrl(repos);
+        const svn::Path target = makeSvnPath(repos);
         const QString path = wc.path();
-        m_pData->m_Svnclient->import(svn::Path(path), svn::Url(target), QString(), svn::DepthInfinity, false, false);
+        m_pData->m_Svnclient->import(path, svn::Url(target), QString(), svn::DepthInfinity, false, false);
     } catch (const svn::ClientException &e) {
         extraError(KIO::ERR_SLAVE_DEFINED, e.msg());
         return;
@@ -979,7 +986,7 @@ void kio_svnProtocol::add(const QUrl &wc)
 void kio_svnProtocol::wc_delete(const QList<QUrl> &urls)
 {
     try {
-        m_pData->m_Svnclient->remove(svn::Targets::fromUrlList(urls), false);
+        m_pData->m_Svnclient->remove(svn::Targets::fromUrlList(urls, svn::Targets::UrlConversion::PreferLocalPath), false);
     } catch (const svn::ClientException &e) {
         extraError(KIO::ERR_SLAVE_DEFINED, e.msg());
         return;
