@@ -34,13 +34,7 @@
 #include <KUrlRequesterDialog>
 
 #include <QStringList>
-#include <QSortFilterProxyModel>
 #include <QTemporaryFile>
-#include <QCheckBox>
-#include <QLabel>
-#include <QLayout>
-#include <QWidget>
-#include <QPushButton>
 #include <QFile>
 
 #define MAX_MESSAGE_HISTORY 10
@@ -54,26 +48,26 @@ Commitmsg_impl::Commitmsg_impl(QWidget *parent)
     : QWidget(parent), CommitMessage()
 {
     setupUi(this);
-    m_CurrentModel = 0;
-    m_SortModel = 0;
+    m_CurrentModel = nullptr;
+    m_SortModel = nullptr;
     m_LogEdit->setFocus();
     m_Reviewlabel->hide();
     m_hidden = true;
     hideButtons(true);
     m_MainSplitter->insertWidget(0, m_EditFrame);
     delete m_ReviewFrame;
-    m_Reviewlabel = 0;
-    m_MarkUnversioned = 0;
-    m_UnmarkUnversioned = 0;
-    m_DiffItem = 0;
+    m_Reviewlabel = nullptr;
+    m_MarkUnversioned = nullptr;
+    m_UnmarkUnversioned = nullptr;
+    m_DiffItem = nullptr;
 }
 
 Commitmsg_impl::Commitmsg_impl(const svn::CommitItemList &_items, QWidget *parent)
     : QWidget(parent), CommitMessage()
 {
     setupUi(this);
-    m_CurrentModel = 0;
-    m_SortModel = 0;
+    m_CurrentModel = nullptr;
+    m_SortModel = nullptr;
     m_LogEdit->setFocus();
     hideButtons(true);
     if (!_items.isEmpty()) {
@@ -94,8 +88,8 @@ Commitmsg_impl::Commitmsg_impl(const CommitActionEntries &_activatedList,
     : QWidget(parent), CommitMessage()
 {
     setupUi(this);
-    m_CurrentModel = 0;
-    m_SortModel = 0;
+    m_CurrentModel = nullptr;
+    m_SortModel = nullptr;
     m_LogEdit->setFocus();
     m_hidden = false;
 
@@ -127,8 +121,8 @@ void Commitmsg_impl::setupModel()
     m_CommitItemTree->resizeColumnToContents(m_CurrentModel->ActionColumn());
 
     m_SortModel->setSortCaseSensitivity(Kdesvnsettings::case_sensitive_sort() ? Qt::CaseSensitive : Qt::CaseInsensitive);
-    connect(m_CommitItemTree->selectionModel(), SIGNAL(currentChanged(QModelIndex,QModelIndex)),
-            this, SLOT(slotCurrentItemChanged(QModelIndex)));
+    connect(m_CommitItemTree->selectionModel(), &QItemSelectionModel::currentChanged,
+            this, &Commitmsg_impl::slotCurrentItemChanged);
     slotCurrentItemChanged(QModelIndex()); // update pushbuttons
 }
 
@@ -199,7 +193,7 @@ void Commitmsg_impl::initHistory()
         KConfigGroup cs(Kdesvnsettings::self()->config(), "log_messages");
         QString s;
         int current = 0;
-        QString key = QString("log_%0").arg(current);
+        QString key = QStringLiteral("log_%0").arg(current);
         s = cs.readEntry(key, QString());
         while (!s.isNull()) {
             if (current < smax_message_history) {
@@ -208,7 +202,7 @@ void Commitmsg_impl::initHistory()
                 cs.deleteEntry(key);
             }
             ++current;
-            key = QString("log_%0").arg(current);
+            key = QStringLiteral("log_%0").arg(current);
             s = cs.readEntry(key, QString());
         }
     }
@@ -217,7 +211,7 @@ void Commitmsg_impl::initHistory()
         if ((*it).length() <= 40) {
             m_LogHistory->addItem((*it));
         } else {
-            m_LogHistory->addItem((*it).left(37) + "...");
+            m_LogHistory->addItem((*it).left(37) + QStringLiteral("..."));
         }
     }
     if (!sLastMessage.isEmpty()) {
@@ -247,7 +241,7 @@ void Commitmsg_impl::saveHistory(bool canceld)
         }
         KConfigGroup cs(Kdesvnsettings::self()->config(), "log_messages");
         for (int i = 0; i < sLogHistory.size(); ++i) {
-            cs.writeEntry(QString("log_%0").arg(i), sLogHistory[i]);
+            cs.writeEntry(QStringLiteral("log_%0").arg(i), sLogHistory[i]);
         }
         cs.sync();
     } else {
@@ -290,7 +284,7 @@ QString Commitmsg_impl::getLogmessageInternal(Commitmsg_impl *ptr, bool *ok, svn
     QString msg;
 
     QPointer<KSvnSimpleOkDialog> dlg(new KSvnSimpleOkDialog(QStringLiteral("logmsg_dlg_size"), parent));
-    dlg->setWindowTitle(i18n("Commit log"));
+    dlg->setWindowTitle(i18nc("@title:window", "Commit Log"));
     dlg->setWithCancelButton();
     dlg->addWidget(ptr);
 
@@ -340,7 +334,7 @@ void Commitmsg_impl::addItemWidget(QWidget *aWidget)
     m_DepthSelector->addItemWidget(aWidget);
 }
 
-CommitActionEntries Commitmsg_impl::checkedEntries()
+CommitActionEntries Commitmsg_impl::checkedEntries() const
 {
     if (m_CurrentModel) {
         return m_CurrentModel->checkedEntries();
@@ -479,12 +473,12 @@ void Commitmsg_impl::insertFile(const QString &fname)
 
 void Commitmsg_impl::insertFile()
 {
-    QString head = i18n("Select text file for insert");
-    QPointer<KUrlRequesterDialog> dlg(new KUrlRequesterDialog(QUrl(), head, this));
-    dlg->setWindowTitle(head);
+    QString windowTitle = i18nc("@title:window", "Select Text File to Insert");
+    QPointer<KUrlRequesterDialog> dlg(new KUrlRequesterDialog(QUrl(), i18n("Select text file to insert:"), this));
+    dlg->setWindowTitle(windowTitle);
     KFile::Mode mode = static_cast<KFile::Mode>(KFile::File);
     dlg->urlRequester()->setMode(mode);
-    dlg->urlRequester()->setWindowTitle(head);
+    dlg->urlRequester()->setWindowTitle(windowTitle);
 
     if (dlg->exec() != QDialog::Accepted) {
         delete dlg;
