@@ -128,7 +128,7 @@ void DiffBrowser::startSearch()
         m_srchdialog->setHasCursor(false);
         m_srchdialog->setHasSelection(false);
         m_srchdialog->setSupportsRegularExpressionFind(false);
-        connect(m_srchdialog, SIGNAL(okClicked()), this, SLOT(search_slot()));
+        connect(m_srchdialog, &KFindDialog::okClicked, this, &DiffBrowser::search_slot);
     }
     QString _st = m_srchdialog->pattern();
     m_srchdialog->setPattern(_st.isEmpty() ? m_pattern : _st);
@@ -152,7 +152,7 @@ void DiffBrowser::doSearch(const QString &to_find_string, bool back)
     if (!m_srchdialog) {
         return;
     }
-    while (1) {
+    while (true) {
         bool result;
         QTextDocument::FindFlags f;
         if (back) {
