@@ -21,17 +21,15 @@
 #define DIFFSYNTAX_H
 
 #include <QSyntaxHighlighter>
-class QTextDocument;
 
 class DiffSyntax : public QSyntaxHighlighter
 {
     Q_OBJECT
 public:
-    explicit DiffSyntax(QTextDocument *aTextEdit);
-    virtual ~DiffSyntax();
+  using QSyntaxHighlighter::QSyntaxHighlighter;
 
 protected:
-    void highlightBlock(const QString &aText);
+    void highlightBlock(const QString &aText) override;
 };
 
 #endif
