@@ -25,30 +25,27 @@
 #include "commitmodelhelper.h"
 #include "svnqt/svnqttypes.h"
 
-#include <QAbstractListModel>
-#include <QScopedPointer>
+#include <QAbstractItemModel>
 #include <QSortFilterProxyModel>
 
 class CommitModel: public QAbstractItemModel
 {
     Q_OBJECT
 protected:
-    explicit CommitModel(const CommitActionEntries &, const CommitActionEntries &, QObject *parent = 0);
+    explicit CommitModel(const CommitActionEntries &, const CommitActionEntries &, QObject *parent = nullptr);
     void setCommitData(const CommitActionEntries &, const CommitActionEntries &);
 public:
-    explicit CommitModel(const svn::CommitItemList &, QObject *parent = 0);
+    explicit CommitModel(const svn::CommitItemList &, QObject *parent = nullptr);
     void setCommitData(const svn::CommitItemList &);
 
-    virtual ~CommitModel();
+    QModelIndex index(int row, int column = 0, const QModelIndex &parent = QModelIndex())const override;
+    QModelIndex parent(const QModelIndex &)const override;
+    QVariant data(const QModelIndex &index, int role) const override;
 
-    virtual QModelIndex index(int row, int column = 0, const QModelIndex &parent = QModelIndex())const;
-    virtual QModelIndex parent(const QModelIndex &)const;
-    QVariant data(const QModelIndex &index, int role) const;
+    int rowCount(const QModelIndex &) const override;
+    int columnCount(const QModelIndex &) const override;
 
-    virtual int rowCount(const QModelIndex &) const;
-    virtual int columnCount(const QModelIndex &) const;
-
-    virtual QVariant headerData(int section, Qt::Orientation orientation, int role = Qt::DisplayRole) const;
+    QVariant headerData(int section, Qt::Orientation orientation, int role = Qt::DisplayRole) const override;
 
     virtual int ActionColumn()const;
     virtual int ItemColumn()const;
@@ -63,36 +60,34 @@ protected:
     CommitModelNodeList m_List;
 };
 
-class CommitModelCheckitem: public CommitModel
+class CommitModelCheckitem : public CommitModel
 {
     Q_OBJECT
 public:
-    CommitModelCheckitem(const CommitActionEntries &, const CommitActionEntries &, QObject *parent = 0);
-    virtual ~CommitModelCheckitem();
+    CommitModelCheckitem(const CommitActionEntries &, const CommitActionEntries &, QObject *parent = nullptr);
 
-    virtual Qt::ItemFlags flags(const QModelIndex &index) const;
-    QVariant data(const QModelIndex &index, int role) const;
+    Qt::ItemFlags flags(const QModelIndex &index) const override;
+    QVariant data(const QModelIndex &index, int role) const override;
 
-    virtual bool setData(const QModelIndex &index, const QVariant &value, int role = Qt::EditRole);
-    virtual int ActionColumn()const;
-    virtual int ItemColumn()const;
+    bool setData(const QModelIndex &index, const QVariant &value, int role = Qt::EditRole) override;
+    int ActionColumn() const override;
+    int ItemColumn() const override;
 
 };
 
-class CommitFilterModel : public QSortFilterProxyModel
+class CommitFilterModel final : public QSortFilterProxyModel
 {
     Q_OBJECT
  public:
-    explicit CommitFilterModel(QObject *parent);
-    ~CommitFilterModel();
-
-    void setSourceModel(QAbstractItemModel *sourceModel);
-    bool filterAcceptsRow(int source_row, const QModelIndex &source_parent) const;
+    using QSortFilterProxyModel::QSortFilterProxyModel;
 
+    void setSourceModel(QAbstractItemModel *sourceModel) override;
     void hideItems(bool bHide, CommitActionEntry::ACTION_TYPE aType);
+protected:
+    bool filterAcceptsRow(int source_row, const QModelIndex &source_parent) const override;
 private:
-    CommitModel *m_sourceModel;
-    CommitActionEntry::ActionTypes m_visibleTypes;
+    CommitModel *m_sourceModel = nullptr;
+    CommitActionEntry::ActionTypes m_visibleTypes = CommitActionEntry::ALL;
 };
 
 #endif
