@@ -29,34 +29,35 @@
 #include <klocalizedstring.h>
 
 static const char description[] =
-    I18N_NOOP("A Subversion Client for KDE (standalone application)");
+    I18N_NOOP("A Subversion Client by KDE (standalone application)");
 
 int main(int argc, char **argv)
 {
     QApplication app(argc, argv);
-    app.setApplicationName("kdesvn");
-    app.setApplicationDisplayName("kdesvn");
-    app.setOrganizationDomain("kde.org");
-    app.setApplicationVersion(KDESVN_VERSION);
-    app.setWindowIcon(QIcon::fromTheme(QLatin1String("kdesvn")));
+    KLocalizedString::setApplicationDomain("kdesvn");
+    app.setApplicationName(QStringLiteral("kdesvn"));
+    app.setApplicationDisplayName(QStringLiteral("kdesvn"));
+    app.setOrganizationDomain(QStringLiteral("kde.org"));
+    app.setApplicationVersion(QStringLiteral(KDESVN_VERSION));
+    app.setWindowIcon(QIcon::fromTheme(QStringLiteral("kdesvn"), app.windowIcon()));
 
-    KAboutData aboutData(QLatin1String("kdesvn"), i18n("kdesvn"), QString(KDESVN_VERSION), i18n(description),
-                         KAboutLicense::GPL, i18n("(C) 2005-2009 Rajko Albrecht,\n(C) 2015-2016 Christian Ehrlicher"));
-    aboutData.addAuthor(i18n("Rajko Albrecht"), i18n("Developer"), QString("ral@alwins-world.de"));
-    aboutData.addAuthor(i18n("Christian Ehrlicher"), i18n("Developer"), QLatin1String("ch.ehrlicher@gmx.de"));
-    aboutData.setHomepage("https://commits.kde.org/kdesvn");
+    KAboutData aboutData(QStringLiteral("kdesvn"), i18n("kdesvn"), QStringLiteral(KDESVN_VERSION), i18n(description),
+                         KAboutLicense::GPL, i18n("(C) 2005-2009 Rajko Albrecht,\n(C) 2015-2019 Christian Ehrlicher"));
+    aboutData.addAuthor(i18n("Rajko Albrecht"), i18n("Developer"), QStringLiteral("ral@alwins-world.de"));
+    aboutData.addAuthor(i18n("Christian Ehrlicher"), i18n("Developer"), QStringLiteral("ch.ehrlicher@gmx.de"));
+    aboutData.setHomepage(QStringLiteral("https://commits.kde.org/kdesvn"));
     KAboutData::setApplicationData(aboutData);
 
     QCommandLineParser parser;
     parser.addVersionOption();
     parser.addHelpOption();
-    parser.addOption({"r", i18n("Execute single Subversion command on specific revision(-range)"), i18n("startrev[:endrev]")});
-    parser.addOption({"R", i18n("Ask for revision when executing single command")});
-    parser.addOption({"f", i18n("Force operation")});
-    parser.addOption({"o", i18n("Save output of Subversion command (eg \"cat\") into file <file>"), i18n("<file>")});
-    parser.addOption({"l", i18n("Limit log output to <number>"), i18n("<number>")});
-    parser.addPositionalArgument("+exec <command>", i18n("Execute Subversion command (\"exec help\" for more information)"));
-    parser.addPositionalArgument("+[URL]", i18n("Document to open"));
+    parser.addOption({QStringLiteral("r"), i18n("Execute single Subversion command on specific revision(-range)"), i18n("startrev[:endrev]")});
+    parser.addOption({QStringLiteral("R"), i18n("Ask for revision when executing single command")});
+    parser.addOption({QStringLiteral("f"), i18n("Force operation")});
+    parser.addOption({QStringLiteral("o"), i18n("Save output of Subversion command (eg \"cat\") into file <file>"), i18n("<file>")});
+    parser.addOption({QStringLiteral("l"), i18n("Limit log output to <number>"), i18n("<number>")});
+    parser.addPositionalArgument(QStringLiteral("+exec <command>"), i18n("Execute Subversion command (\"exec help\" for more information)"));
+    parser.addPositionalArgument(QStringLiteral("+[URL]"), i18n("Document to open"));
     aboutData.setupCommandLine(&parser);
     parser.process(app);
     aboutData.processCommandLine(&parser);
