@@ -75,8 +75,8 @@ pCPart::pCPart()
     , single_revision(false)
     , force(false)
     , log_limit(0)
-    , m_SvnWrapper(NULL)
-    , parser(NULL)
+    , m_SvnWrapper(nullptr)
+    , parser(nullptr)
     , start(svn::Revision::UNDEFINED)
     , end(svn::Revision::UNDEFINED)
     , Stdout(stdout)
@@ -97,12 +97,12 @@ CommandExec::CommandExec(QObject *parent)
     , m_lastMessagesLines(0)
 {
     m_pCPart = new pCPart;
-    m_pCPart->parser = 0;
+    m_pCPart->parser = nullptr;
     SshAgent ag;
     ag.querySshAgent();
 
-    connect(m_pCPart->m_SvnWrapper, SIGNAL(clientException(QString)), this, SLOT(clientException(QString)));
-    connect(m_pCPart->m_SvnWrapper, SIGNAL(sendNotify(QString)), this, SLOT(slotNotifyMessage(QString)));
+    connect(m_pCPart->m_SvnWrapper, &SvnActions::clientException, this, &CommandExec::clientException);
+    connect(m_pCPart->m_SvnWrapper, &SvnActions::sendNotify, this, &CommandExec::slotNotifyMessage);
     m_pCPart->m_SvnWrapper->reInitClient();
 }
 
@@ -133,81 +133,81 @@ int CommandExec::exec(const QCommandLineParser *parser)
         m_pCPart->cmd = m_pCPart->cmd.toLower();
     }
     QByteArray slotCmd;
-    if (!QString::compare(m_pCPart->cmd, "log")) {
+    if (!QString::compare(m_pCPart->cmd, QLatin1String("log"))) {
         slotCmd = SLOT(slotCmd_log());
-    } else if (!QString::compare(m_pCPart->cmd, "cat")) {
+    } else if (!QString::compare(m_pCPart->cmd, QLatin1String("cat"))) {
         slotCmd = SLOT(slotCmd_cat());
         m_pCPart->single_revision = true;
-    } else if (!QString::compare(m_pCPart->cmd, "get")) {
+    } else if (!QString::compare(m_pCPart->cmd, QLatin1String("get"))) {
         slotCmd = SLOT(slotCmd_get());
         m_pCPart->single_revision = true;
-    } else if (!QString::compare(m_pCPart->cmd, "help")) {
+    } else if (!QString::compare(m_pCPart->cmd, QLatin1String("help"))) {
         slotCmd = SLOT(slotCmd_help());
-    } else if (!QString::compare(m_pCPart->cmd, "blame") ||
-               !QString::compare(m_pCPart->cmd, "annotate")) {
+    } else if (!QString::compare(m_pCPart->cmd, QLatin1String("blame")) ||
+               !QString::compare(m_pCPart->cmd, QLatin1String("annotate"))) {
         slotCmd = SLOT(slotCmd_blame());
-    } else if (!QString::compare(m_pCPart->cmd, "update")) {
+    } else if (!QString::compare(m_pCPart->cmd, QLatin1String("update"))) {
         slotCmd = SLOT(slotCmd_update());
         m_pCPart->single_revision = true;
-    } else if (!QString::compare(m_pCPart->cmd, "diff")) {
+    } else if (!QString::compare(m_pCPart->cmd, QLatin1String("diff"))) {
         m_pCPart->start = svn::Revision::WORKING;
         slotCmd = SLOT(slotCmd_diff());
-    } else if (!QString::compare(m_pCPart->cmd, "info")) {
+    } else if (!QString::compare(m_pCPart->cmd, QLatin1String("info"))) {
         slotCmd = SLOT(slotCmd_info());
         m_pCPart->single_revision = true;
-    } else if (!QString::compare(m_pCPart->cmd, "commit") ||
-               !QString::compare(m_pCPart->cmd, "ci")) {
+    } else if (!QString::compare(m_pCPart->cmd, QLatin1String("commit")) ||
+               !QString::compare(m_pCPart->cmd, QLatin1String("ci"))) {
         slotCmd = SLOT(slotCmd_commit());
-    } else if (!QString::compare(m_pCPart->cmd, "list") ||
-               !QString::compare(m_pCPart->cmd, "ls")) {
+    } else if (!QString::compare(m_pCPart->cmd, QLatin1String("list")) ||
+               !QString::compare(m_pCPart->cmd, QLatin1String("ls"))) {
         slotCmd = SLOT(slotCmd_list());
-    } else if (!QString::compare(m_pCPart->cmd, "copy") ||
-               !QString::compare(m_pCPart->cmd, "cp")) {
+    } else if (!QString::compare(m_pCPart->cmd, QLatin1String("copy")) ||
+               !QString::compare(m_pCPart->cmd, QLatin1String("cp"))) {
         slotCmd = SLOT(slotCmd_copy());
         dont_check_second = true;
-    } else if (!QString::compare(m_pCPart->cmd, "move") ||
-               !QString::compare(m_pCPart->cmd, "rename") ||
-               !QString::compare(m_pCPart->cmd, "mv")) {
+    } else if (!QString::compare(m_pCPart->cmd, QLatin1String("move")) ||
+               !QString::compare(m_pCPart->cmd, QLatin1String("rename")) ||
+               !QString::compare(m_pCPart->cmd, QLatin1String("mv"))) {
         slotCmd = SLOT(slotCmd_move());
         dont_check_second = true;
-    } else if (!QString::compare(m_pCPart->cmd, "checkout") ||
-               !QString::compare(m_pCPart->cmd, "co")) {
+    } else if (!QString::compare(m_pCPart->cmd, QLatin1String("checkout")) ||
+               !QString::compare(m_pCPart->cmd, QLatin1String("co"))) {
         slotCmd = SLOT(slotCmd_checkout());
         dont_check_second = true;
-    } else if (!QString::compare(m_pCPart->cmd, "checkoutto") ||
-               !QString::compare(m_pCPart->cmd, "coto")) {
+    } else if (!QString::compare(m_pCPart->cmd, QLatin1String("checkoutto")) ||
+               !QString::compare(m_pCPart->cmd, QLatin1String("coto"))) {
         slotCmd = SLOT(slotCmd_checkoutto());
         dont_check_second = true;
-    } else if (!QString::compare(m_pCPart->cmd, "export")) {
+    } else if (!QString::compare(m_pCPart->cmd, QLatin1String("export"))) {
         slotCmd = SLOT(slotCmd_export());
         dont_check_second = true;
-    } else if (!QString::compare(m_pCPart->cmd, "exportto")) {
+    } else if (!QString::compare(m_pCPart->cmd, QLatin1String("exportto"))) {
         slotCmd = SLOT(slotCmd_exportto());
         dont_check_second = true;
-    } else if (!QString::compare(m_pCPart->cmd, "delete") ||
-               !QString::compare(m_pCPart->cmd, "del") ||
-               !QString::compare(m_pCPart->cmd, "rm") ||
-               !QString::compare(m_pCPart->cmd, "remove")) {
+    } else if (!QString::compare(m_pCPart->cmd, QLatin1String("delete")) ||
+               !QString::compare(m_pCPart->cmd, QLatin1String("del")) ||
+               !QString::compare(m_pCPart->cmd, QLatin1String("rm")) ||
+               !QString::compare(m_pCPart->cmd, QLatin1String("remove"))) {
         slotCmd = SLOT(slotCmd_delete());
-    } else if (!QString::compare(m_pCPart->cmd, "add")) {
+    } else if (!QString::compare(m_pCPart->cmd, QLatin1String("add"))) {
         slotCmd = SLOT(slotCmd_add());
         dont_check_all = true;
         path_only = true;
-    } else if (!QString::compare(m_pCPart->cmd, "undo") ||
-               !QString::compare(m_pCPart->cmd, "revert")) {
+    } else if (!QString::compare(m_pCPart->cmd, QLatin1String("undo")) ||
+               !QString::compare(m_pCPart->cmd, QLatin1String("revert"))) {
         slotCmd = SLOT(slotCmd_revert());
-    } else if (!QString::compare(m_pCPart->cmd, "checknew") ||
-               !QString::compare(m_pCPart->cmd, "addnew")) {
+    } else if (!QString::compare(m_pCPart->cmd, QLatin1String("checknew")) ||
+               !QString::compare(m_pCPart->cmd, QLatin1String("addnew"))) {
         slotCmd = SLOT(slotCmd_addnew());
-    } else if (!QString::compare(m_pCPart->cmd, "switch")) {
+    } else if (!QString::compare(m_pCPart->cmd, QLatin1String("switch"))) {
         slotCmd = SLOT(slotCmd_switch());
-    } else if (!QString::compare(m_pCPart->cmd, "tree")) {
+    } else if (!QString::compare(m_pCPart->cmd, QLatin1String("tree"))) {
         slotCmd = SLOT(slotCmd_tree());
-    } else if (!QString::compare(m_pCPart->cmd, "lock")) {
+    } else if (!QString::compare(m_pCPart->cmd, QLatin1String("lock"))) {
         slotCmd = SLOT(slotCmd_lock());
         no_revision = true;
         check_force = true;
-    } else if (!QString::compare(m_pCPart->cmd, "unlock")) {
+    } else if (!QString::compare(m_pCPart->cmd, QLatin1String("unlock"))) {
         slotCmd = SLOT(slotCmd_unlock());
         no_revision = true;
         check_force = true;
@@ -215,7 +215,7 @@ int CommandExec::exec(const QCommandLineParser *parser)
 
     bool found = connect(this, SIGNAL(executeMe()), this, slotCmd.constData());
     if (!found) {
-        KMessageBox::sorry(0,
+        KMessageBox::sorry(nullptr,
                            i18n("Command \"%1\" not implemented or known", m_pCPart->cmd),
                            i18n("SVN Error"));
         return -1;
@@ -227,7 +227,7 @@ int CommandExec::exec(const QCommandLineParser *parser)
         QUrl tmpurl = QUrl::fromUserInput(m_pCPart->args.at(j),
                                           QDir::currentPath());
         tmpurl.setScheme(svn::Url::transformProtokoll(tmpurl.scheme()));
-        if (tmpurl.scheme().indexOf(QLatin1String("ssh")) != -1) {
+        if (tmpurl.scheme().contains(QLatin1String("ssh"))) {
             SshAgent ag;
             // this class itself checks if done before
             ag.addSshIdentities();
@@ -262,9 +262,9 @@ int CommandExec::exec(const QCommandLineParser *parser)
                 tmp = tmpurl.path();
             }
         }
-        const QStringList l = tmp.split(QLatin1Char('?'), QString::SkipEmptyParts);
+        const QVector<QStringRef> l = tmp.splitRef(QLatin1Char('?'), QString::SkipEmptyParts);
         if (!l.isEmpty()) {
-            tmp = l[0];
+            tmp = l.first().toString();
         }
         while (tmp.endsWith(QLatin1Char('/'))) {
             tmp.chop(1);
@@ -274,9 +274,9 @@ int CommandExec::exec(const QCommandLineParser *parser)
             continue;
         }
         const QList<QPair<QString, QString> > q = QUrlQuery(tmpurl).queryItems();
-        for(int i = 0; i < q.size(); ++i) {
-            if (q.at(i).first == QLatin1String("rev")) {
-                svn::Revision re = q.at(i).second;
+        for (const auto &item : q) {
+            if (item.first == QLatin1String("rev")) {
+                svn::Revision re = item.second;
                 if (re) {
                     m_pCPart->extraRevisions[j - 2] = re;
                 }
@@ -336,7 +336,7 @@ int CommandExec::exec(const QCommandLineParser *parser)
 void CommandExec::clientException(const QString &what)
 {
     m_pCPart->Stderr << what << endl;
-    KMessageBox::sorry(0, what, i18n("SVN Error"));
+    KMessageBox::sorry(nullptr, what, i18n("SVN Error"));
 }
 
 
@@ -419,7 +419,7 @@ void CommandExec::slotCmd_cat()
     }
     m_pCPart->m_SvnWrapper->slotMakeCat(
         (m_pCPart->rev_set ? m_pCPart->start : m_pCPart->end), m_pCPart->urls.at(0), m_pCPart->urls.at(0)
-        , (m_pCPart->rev_set ? m_pCPart->start : m_pCPart->end), 0);
+        , (m_pCPart->rev_set ? m_pCPart->start : m_pCPart->end), nullptr);
 }
 
 void CommandExec::slotCmd_get()
@@ -500,7 +500,7 @@ void CommandExec::slotCmd_list()
     if (!m_pCPart->m_SvnWrapper->makeList(m_pCPart->urls.at(0), res, rev, svn::DepthInfinity)) {
         return;
     }
-    Q_FOREACH(const svn::DirEntry &entry, res) {
+    for (const svn::DirEntry &entry : qAsConst(res)) {
         QString d = entry.time().toString(QStringLiteral("yyyy-MM-dd hh:mm::ss"));
         m_pCPart->Stdout
                 << (entry.kind() == svn_node_dir ? "D" : "F") << " "
@@ -515,7 +515,7 @@ void CommandExec::slotCmd_copy()
     if (m_pCPart->urls.count() < 2) {
         bool ok;
         target = CopyMoveView_impl::getMoveCopyTo(&ok, false,
-                                                  m_pCPart->urls.at(0), QString(), 0);
+                                                  m_pCPart->urls.at(0), QString(), nullptr);
         if (!ok) {
             return;
         }
@@ -538,7 +538,7 @@ void CommandExec::slotCmd_move()
     QString target;
     if (m_pCPart->urls.count() < 2) {
         target = CopyMoveView_impl::getMoveCopyTo(&ok, true,
-                                                  m_pCPart->urls.at(0), QString(), 0);
+                                                  m_pCPart->urls.at(0), QString(), nullptr);
         if (!ok) {
             return;
         }
@@ -573,14 +573,14 @@ void CommandExec::slotCmd_addnew()
  */
 bool CommandExec::scanRevision()
 {
-    QString revstring = m_pCPart->parser->value("r");
-    QStringList revl = revstring.split(':', QString::SkipEmptyParts);
-    if (revl.count() == 0) {
+    const QString revstring = m_pCPart->parser->value(QStringLiteral("r"));
+    const QVector<QStringRef> revl = revstring.splitRef(QLatin1Char(':'), QString::SkipEmptyParts);
+    if (revl.isEmpty()) {
         return false;
     }
-    m_pCPart->start = revl[0];
+    m_pCPart->start = revl[0].toString();
     if (revl.count() > 1) {
-        m_pCPart->end = revl[1];
+        m_pCPart->end = revl[1].toString();
     }
     m_pCPart->rev_set = true;
     return true;
