@@ -42,7 +42,7 @@ protected Q_SLOTS:
 private:
     void init();
     explicit DbSettings(const QString &repository, QWidget *parent = nullptr);
-    virtual ~DbSettings();
+    ~DbSettings();
 
     void store_list(KEditListWidget *, const QString &);
 private:
