@@ -28,8 +28,8 @@ class CheckoutInfo_impl: public QWidget, public Ui::CheckoutInfo
 {
     Q_OBJECT
 public:
-    explicit CheckoutInfo_impl(QWidget *parent = 0);
-    virtual ~CheckoutInfo_impl();
+    explicit CheckoutInfo_impl(QWidget *parent = nullptr);
+    ~CheckoutInfo_impl();
 
     svn::Revision toRevision() const;
     QUrl reposURL() const;
@@ -43,13 +43,11 @@ public:
     void disableTargetDir(bool how);
     void disableAppend(bool how);
     void disableOpen(bool how);
-    void disableExternals(bool how);
     bool openAfterJob() const;
     void disableRange(bool how);
     void setTargetUrl(const QUrl &);
     bool ignoreExternals() const;
     void hideDepth(bool hide);
-    void overwriteAsRecursive();
     void hideOverwrite(bool hide);
     void hideIgnoreKeywords(bool hide);
     bool ignoreKeywords() const;
