@@ -31,7 +31,7 @@
 
 #include <QFileDialog>
 #include <QFontDatabase>
-#include <QMatrix>
+#include <QTransform>
 #include <QMenu>
 #include <QPainter>
 #include <QRegExp>
@@ -51,18 +51,18 @@
 
 RevGraphView::RevGraphView(const svn::ClientP &_client, QWidget *parent)
     : QGraphicsView(parent)
-    , m_Scene(0)
-    , m_Marker(0)
+    , m_Scene(nullptr)
+    , m_Marker(nullptr)
     , m_Client(_client)
-    , m_Selected(0)
-    , m_dotTmpFile(0)
-    , m_renderProcess(0)
+    , m_Selected(nullptr)
+    , m_dotTmpFile(nullptr)
+    , m_renderProcess(nullptr)
     , m_xMargin(0)
     , m_yMargin(0)
     , m_CompleteView(new PannerView(this))
     , m_cvZoom(0)
     , m_LastAutoPosition(TopLeft)
-    , m_isMoving(0)
+    , m_isMoving(false)
     , m_noUpdateZoomerPos(false)
 
 {
@@ -70,15 +70,15 @@ RevGraphView::RevGraphView(const svn::ClientP &_client, QWidget *parent)
     m_CompleteView->setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
     m_CompleteView->raise();
     m_CompleteView->hide();
-    connect(m_CompleteView, SIGNAL(zoomRectMoved(qreal,qreal)),
-            this, SLOT(zoomRectMoved(qreal,qreal)));
-    connect(m_CompleteView, SIGNAL(zoomRectMoveFinished()),
-            this, SLOT(zoomRectMoveFinished()));
+    connect(m_CompleteView, &PannerView::zoomRectMoved,
+            this, &RevGraphView::zoomRectMoved);
+    connect(m_CompleteView, &PannerView::zoomRectMoveFinished,
+            this, &RevGraphView::zoomRectMoveFinished);
 }
 
 RevGraphView::~RevGraphView()
 {
-    setScene(0);
+    setScene(nullptr);
     delete m_Scene;
     delete m_dotTmpFile;
     delete m_CompleteView;
@@ -99,17 +99,17 @@ void RevGraphView::clear()
 {
     if (m_Selected) {
         m_Selected->setSelected(false);
-        m_Selected = 0;
+        m_Selected = nullptr;
     }
     if (m_Marker) {
         m_Marker->hide();
         delete m_Marker;
-        m_Marker = 0;
+        m_Marker = nullptr;
     }
-    setScene(0);
-    m_CompleteView->setScene(0);
+    setScene(nullptr);
+    m_CompleteView->setScene(nullptr);
     delete m_Scene;
-    m_Scene = 0;
+    m_Scene = nullptr;
 }
 
 void RevGraphView::beginInsert()
@@ -147,7 +147,7 @@ void RevGraphView::dotExit(int exitcode, QProcess::ExitStatus exitStatus)
                              QString::fromLocal8Bit(m_renderProcess->readAllStandardError()));
         showText(error);
         delete m_renderProcess;
-        m_renderProcess = 0;
+        m_renderProcess = nullptr;
         return;
     }
     // remove line breaks when lines to long
@@ -175,11 +175,11 @@ void RevGraphView::dotExit(int exitcode, QProcess::ExitStatus exitStatus)
         }
         QTextStream lineStream(&line, QIODevice::ReadOnly);
         lineStream >> cmd;
-        if (cmd == "stop") {
+        if (cmd == QLatin1String("stop")) {
             break;
         }
 
-        if (cmd == "graph") {
+        if (cmd == QLatin1String("graph")) {
             lineStream >> scale >> dotWidth >> dotHeight;
             int w = qRound(scaleX * dotWidth);
             int h = qRound(scaleY * dotHeight);
@@ -201,7 +201,10 @@ void RevGraphView::dotExit(int exitcode, QProcess::ExitStatus exitStatus)
                        << m_dotTmpFile->fileName() << ":" << lineno << ")" << endl;
             continue;
         }
-        if (cmd == "node") {
+        if (!m_Scene) {
+            continue;
+        }
+        if (cmd == QLatin1String("node")) {
             QString nodeName, label;
             QString _x, _y, _w, _h;
             double x, y, width, height;
@@ -319,7 +322,7 @@ void RevGraphView::dotExit(int exitcode, QProcess::ExitStatus exitStatus)
                 t2 *= 3;
                 a << pa[indexHead] + t1 << pa[indexHead] + arrowDir << pa[indexHead] + t2;
 
-                GraphEdgeArrow *aItem = new GraphEdgeArrow(n, 0);
+                GraphEdgeArrow *aItem = new GraphEdgeArrow(n, nullptr);
                 m_Scene->addItem(aItem);
                 aItem->setPolygon(a);
                 aItem->setBrush(arrowColor);
@@ -341,7 +344,7 @@ void RevGraphView::dotExit(int exitcode, QProcess::ExitStatus exitStatus)
     }
     endInsert();
     delete m_renderProcess;
-    m_renderProcess = 0;
+    m_renderProcess = nullptr;
 }
 
 bool RevGraphView::isStart(const QString &nodeName)const
@@ -509,14 +512,14 @@ void RevGraphView::dumpRevtree()
         }
     }
     stream << "}\n" << flush;
-    m_renderProcess = new KProcess();
+    m_renderProcess = new KProcess;
     m_renderProcess->setEnv("LANG", "C");
     *m_renderProcess << "dot";
     *m_renderProcess << m_dotTmpFile->fileName() << "-Tplain";
-    connect(m_renderProcess, SIGNAL(finished(int,QProcess::ExitStatus)),
-            this, SLOT(dotExit(int,QProcess::ExitStatus)));
-    connect(m_renderProcess, SIGNAL(readyReadStandardOutput()),
-            this, SLOT(readDotOutput()));
+    connect(m_renderProcess, QOverload<int, QProcess::ExitStatus>::of(&QProcess::finished),
+            this, &RevGraphView::dotExit);
+    connect(m_renderProcess, &QProcess::readyReadStandardOutput,
+            this, &RevGraphView::readDotOutput);
     m_renderProcess->setOutputChannelMode(KProcess::SeparateChannels);
     m_renderProcess->start();
 }
@@ -524,24 +527,23 @@ void RevGraphView::dumpRevtree()
 QString RevGraphView::toolTip(const QString &_nodename, bool full)const
 {
     QString res;
-    trevTree::ConstIterator it;
-    it = m_Tree.constFind(_nodename);
+    trevTree::ConstIterator it = m_Tree.constFind(_nodename);
     if (it == m_Tree.constEnd()) {
         return res;
     }
-    const QStringList sp = it.value().Message.split(QLatin1Char('\n'));
+    const QVector<QStringRef> sp = it.value().Message.splitRef(QLatin1Char('\n'));
     QString sm;
     if (sp.isEmpty()) {
         sm = it.value().Message;
     } else {
         if (!full) {
-            sm = sp[0] + QLatin1String("...");
+            sm = sp[0].toString() + QLatin1String("...");
         } else {
             for (int j = 0; j < sp.count(); ++j) {
                 if (j > 0) {
                     sm += QLatin1String("<br/>");
                 }
-                sm += sp[j];
+                sm += sp[j].toString();
             }
         }
     }
@@ -618,8 +620,7 @@ void RevGraphView::updateSizes(QSize s)
 
     if (zoom != m_cvZoom) {
         m_cvZoom = zoom;
-        QMatrix wm;
-        m_CompleteView->setMatrix(wm.scale(zoom, zoom));
+        m_CompleteView->setTransform(QTransform::fromScale(zoom, zoom));
 
         // make it a little bigger to compensate for widget frame
         m_CompleteView->resize(int(cWidth * zoom) + 4,
@@ -730,7 +731,7 @@ void RevGraphView::makeSelected(GraphTreeLabel *gtl)
     if (m_Marker) {
         m_Marker->hide();
         delete m_Marker;
-        m_Marker = 0;
+        m_Marker = nullptr;
     }
     if (gtl) {
         m_Marker = new GraphMark(gtl);
@@ -743,16 +744,16 @@ void RevGraphView::makeSelected(GraphTreeLabel *gtl)
 
 }
 
-GraphTreeLabel *RevGraphView::firstLabelAt(const QPoint &pos)const
+GraphTreeLabel *RevGraphView::firstLabelAt(const QPoint &pos) const
 {
     QList<QGraphicsItem *> its = items(pos);
-    for (QList<QGraphicsItem *>::size_type i = 0; i < its.size(); ++i) {
-        if (its[i]->type() == GRAPHTREE_LABEL) {
-            return static_cast<GraphTreeLabel *>(its[i]);
+    for (auto &it : its) {
+        if (it->type() == GRAPHTREE_LABEL) {
+            return static_cast<GraphTreeLabel *>(it);
         }
     }
 
-    return 0;
+    return nullptr;
 }
 
 void RevGraphView::mouseDoubleClickEvent(QMouseEvent *e)
@@ -760,7 +761,7 @@ void RevGraphView::mouseDoubleClickEvent(QMouseEvent *e)
     setFocus();
     if (e->button() == Qt::LeftButton) {
         GraphTreeLabel *i = firstLabelAt(e->pos());
-        if (i == 0) {
+        if (i == nullptr) {
             return;
         }
         makeSelected(i);
@@ -926,7 +927,7 @@ void RevGraphView::contextMenuEvent(QContextMenuEvent *e)
         }
         break;
     case 401:
-        makeSelected(0);
+        makeSelected(nullptr);
         break;
     case 402:
         makeSelected(i);
