@@ -19,6 +19,7 @@
  ***************************************************************************/
 #include "revisiontree.h"
 #include "../stopdlg.h"
+#include "../ccontextlistener.h"
 #include "svnqt/log_entry.h"
 #include "svnqt/cache/LogCache.h"
 #include "svnqt/cache/ReposLog.h"
@@ -40,6 +41,7 @@
 #define INTERNALCOPY 1
 #define INTERNALRENAME 2
 
+class CContextListener;
 class RtreeData
 {
 public:
@@ -58,7 +60,7 @@ public:
     RevTreeWidget *m_TreeDisplay;
 
     svn::ClientP m_Client;
-    QObject *m_Listener;
+    CContextListener *m_Listener;
 
     bool getLogs(const QString &, const svn::Revision &startr, const svn::Revision &endr, const QString &origin);
 };
@@ -66,10 +68,10 @@ public:
 RtreeData::RtreeData()
     : max_rev(-1), min_rev(-1)
 {
-    progress = 0;
-    m_TreeDisplay = 0;
-    dlgParent = 0;
-    m_Listener = 0;
+    progress = nullptr;
+    m_TreeDisplay = nullptr;
+    dlgParent = nullptr;
+    m_Listener = nullptr;
 }
 
 RtreeData::~RtreeData()
@@ -89,7 +91,7 @@ bool RtreeData::getLogs(const QString &reposRoot, const svn::Revision &startr, c
     try {
         CursorStack a(Qt::BusyCursor);
         StopDlg sdlg(m_Listener, dlgParent,
-                     i18n("Logs"), i18n("Getting logs - hit Cancel for abort"));
+                     i18nc("@title:window", "Logs"), i18n("Getting logs - hit Cancel for abort"));
         if (svn::Url::isLocal(reposRoot)) {
             m_Client->log(params.excludeList(ex), m_OldHistory);
         } else {
@@ -99,19 +101,19 @@ bool RtreeData::getLogs(const QString &reposRoot, const svn::Revision &startr, c
             } else if (Kdesvnsettings::network_on()) {
                 m_Client->log(params.excludeList(ex), m_OldHistory);
             } else {
-                KMessageBox::error(0, i18n("Could not retrieve logs, reason:\n%1", i18n("No log cache possible due broken database and networking not allowed.")));
+                KMessageBox::error(nullptr, i18n("Could not retrieve logs, reason:\n%1", i18n("No log cache possible due broken database and networking not allowed.")));
                 return false;
             }
         }
     } catch (const svn::Exception &ce) {
-        KMessageBox::error(0, i18n("Could not retrieve logs, reason:\n%1", ce.msg()));
+        KMessageBox::error(nullptr, i18n("Could not retrieve logs, reason:\n%1", ce.msg()));
         return false;
     }
     return true;
 }
 
 RevisionTree::RevisionTree(const svn::ClientP &aClient,
-                           QObject *aListener,
+                           CContextListener *aListener,
                            const QString &reposRoot,
                            const svn::Revision &startr, const svn::Revision &endr,
                            const QString &origin,
@@ -130,7 +132,7 @@ RevisionTree::RevisionTree(const svn::ClientP &aClient,
     long possible_rev = -1;
 
     m_Data->progress = new QProgressDialog(i18n("Scanning the logs for %1", origin), i18n("Cancel"), 0, m_Data->m_OldHistory.size(), parent);
-    m_Data->progress->setWindowTitle(i18n("Scanning logs"));
+    m_Data->progress->setWindowTitle(i18nc("@title:window", "Scanning logs"));
     m_Data->progress->setMinimumDuration(100);
     m_Data->progress->setAutoClose(false);
     m_Data->progress->setWindowModality(Qt::WindowModal);
@@ -178,7 +180,7 @@ RevisionTree::RevisionTree(const svn::ClientP &aClient,
                 m_Data->m_TreeDisplay->dumpRevtree();
             } else {
                 delete m_Data->m_TreeDisplay;
-                m_Data->m_TreeDisplay = 0;
+                m_Data->m_TreeDisplay = nullptr;
             }
         }
     }
@@ -326,7 +328,7 @@ bool RevisionTree::isParent(const QString &_par, const QString &tar)
     if (_par == tar) {
         return true;
     }
-    QString par = _par.endsWith('/') ? _par : _par + '/';
+    QString par = _par.endsWith(QLatin1Char('/')) ? _par : _par + QLatin1Char('/');
     return tar.startsWith(par);
 }
 
@@ -500,7 +502,7 @@ bool RevisionTree::bottomUpScan(long startrev, unsigned recurse, const QString &
     return !cancel;
 }
 
-QWidget *RevisionTree::getView()
+RevTreeWidget *RevisionTree::getView()
 {
     return m_Data->m_TreeDisplay;
 }
