@@ -39,15 +39,15 @@ class MainTreeWidget: public QWidget, public Ui::mainTreeWidget, public ItemDisp
 {
     Q_OBJECT
 public:
-    explicit MainTreeWidget(KActionCollection *aCollection, QWidget *parent = 0, Qt::WindowFlags f = 0);
-    virtual ~MainTreeWidget();
+    explicit MainTreeWidget(KActionCollection *aCollection, QWidget *parent = nullptr, Qt::WindowFlags f = nullptr);
+    ~MainTreeWidget();
 
-    virtual QWidget *realWidget();
-    virtual SvnItem *Selected()const;
-    virtual SvnItemList SelectionList()const;
-    virtual svn::Revision baseRevision()const;
-    virtual bool openUrl(const QUrl &url, bool noReinit = false);
-    virtual SvnItem *SelectedOrMain()const;
+    QWidget *realWidget() override;
+    SvnItem *Selected()const override;
+    SvnItemList SelectionList()const override;
+    svn::Revision baseRevision()const override;
+    bool openUrl(const QUrl &url, bool noReinit = false) override;
+    SvnItem *SelectedOrMain()const override;
 
     SvnItem *DirSelected()const;
     QModelIndex SelectedIndex()const;
@@ -66,7 +66,7 @@ Q_SIGNALS:
     void sigExtraStatusMessage(const QString &);
     void changeCaption(const QString &);
     void sigShowPopup(const QString &, QWidget **);
-    void sigUrlOpend(bool);
+    void sigUrlOpened(bool);
     void sigSwitchUrl(const QUrl &);
     void sigUrlChanged(const QUrl &);
     void sigProplist(const svn::PathPropertiesMapListPtr &, bool, bool, const QString &);
@@ -84,13 +84,14 @@ public Q_SLOTS:
     void refreshCurrent(SvnItem *);
     void slotReinitItem(SvnItem *);
     void stopLogCache();
+    void slotChangeProperties(const svn::PropertiesMap &, const QStringList &, const QString &);
 
 protected Q_SLOTS:
     void slotCacheDataChanged();
     void slotItemActivated(const QModelIndex &);
     void slotItemExpanded(const QModelIndex &);
     void slotItemsInserted(const QModelIndex &);
-    void slotRescanIcons();
+    void slotRefreshItem(const QString &path);
     void _propListTimeout();
 
     void slotCheckUpdates();
@@ -119,7 +120,6 @@ protected Q_SLOTS:
     void slotBlame();
     void slotRangeBlame();
     void slotDisplayProperties();
-    void slotChangeProperties(const svn::PropertiesMap &, const QStringList &, const QString &);
     void slotCat();
     void slotRevisionCat();
     void slotResolved();
@@ -143,7 +143,8 @@ protected Q_SLOTS:
     void slotDirUpdate();
     void slotDirRecProperty();
 
-    void slotDirSelectionChanged(const QItemSelection &, const QItemSelection &);
+    void slotDirSelectionChanged(const QItemSelection &_item, const QItemSelection &);
+    void checkSyncTreeModel();
 
     void _openUrl(const QUrl &);
     void enableActions();
@@ -164,7 +165,7 @@ protected Q_SLOTS:
 
     void resizeAllColumns();
 protected:
-    virtual void keyPressEvent(QKeyEvent *);
+    void keyPressEvent(QKeyEvent *) override;
     void setupActions();
     bool uniqueTypeSelected();
     KService::List offersList(SvnItem *item, bool execOnly = false)const;
