@@ -33,8 +33,8 @@ LogChangePathItem::LogChangePathItem(const svn::LogChangePathEntry &e, QTreeWidg
 
 void LogChangePathItem::init(const svn::LogChangePathEntry &e)
 {
-    _action = QChar(e.action);
-    setText(0, _action);
+    _action = e.action;
+    setText(0, QString(QLatin1Char(_action)));
     _path = e.path;
     setText(1, e.path);
     _revision = e.copyFromRevision;
@@ -84,7 +84,7 @@ bool SvnLogModelNode::isParent(const QString &_par, const QString &tar)
     if (_par == tar) {
         return true;
     }
-    QString par = _par.endsWith('/') ? _par : _par + '/';
+    QString par = _par.endsWith(QLatin1Char('/')) ? _par : _par + QLatin1Char('/');
     return tar.startsWith(par);
 }
 
