@@ -51,7 +51,7 @@ class SvnItemModelData
     SvnItemModelData &operator=(const SvnItemModelData &);
 public:
     SvnItemModelData(SvnItemModel *aCb, MainTreeWidget *display)
-        : m_rootNode(0), m_SvnActions(NULL), m_Cb(aCb), m_Display(display), m_DirWatch(NULL)
+        : m_rootNode(nullptr), m_SvnActions(nullptr), m_Cb(aCb), m_Display(display), m_DirWatch(nullptr)
     {
         m_Uid = QUuid::createUuid().toString();
         m_InfoThread = new GetInfoThread(aCb);
@@ -67,14 +67,14 @@ public:
 
         delete m_rootNode;
         delete m_DirWatch;
-        m_rootNode = 0;
+        m_rootNode = nullptr;
     }
 
     void clear()
     {
         delete m_rootNode;
         delete m_DirWatch;
-        m_DirWatch = 0;
+        m_DirWatch = nullptr;
         m_rootNode = new SvnItemModelNodeDir(m_SvnActions, m_Display);
     }
 
@@ -150,7 +150,7 @@ SvnItemModel::~SvnItemModel()
 SvnItemModelNode *SvnItemModel::firstRootChild()
 {
     if (!m_Data->m_rootNode) {
-        return 0;
+        return nullptr;
     }
     return m_Data->m_rootNode->child(0);
 }
@@ -173,9 +173,11 @@ void SvnItemModel::setRootNodeStat(const svn::StatusPtr &stat)
 void SvnItemModel::clear()
 {
     int numRows = m_Data->m_rootNode->childList().count();
-    beginRemoveRows(QModelIndex(), 0, numRows);
+    if (numRows > 0)
+        beginRemoveRows(QModelIndex(), 0, numRows - 1);
     m_Data->clear();
-    endRemoveRows();
+    if (numRows > 0)
+        endRemoveRows();
 }
 
 void SvnItemModel::beginRemoveRows(const QModelIndex &parent, int first, int last)
@@ -385,7 +387,7 @@ int SvnItemModel::checkDirs(const QString &_what, SvnItemModelNode *_parent)
     svnWrapper()->getaddedItems(what, neweritems);
     dlist += neweritems;
     svn::StatusEntries::iterator it = dlist.begin();
-    SvnItemModelNode *node = 0;
+    SvnItemModelNode *node = nullptr;
     for (; it != dlist.end(); ++it) {
         if ((*it)->path() == what || (*it)->entry().url().toString() == what) {
             if (!_parent) {
@@ -426,7 +428,7 @@ void SvnItemModel::insertDirs(SvnItemModelNode *_parent, svn::StatusEntries &dli
     } else {
         parent = static_cast<SvnItemModelNodeDir *>(_parent);
     }
-    SvnItemModelNode *node = 0;
+    SvnItemModelNode *node = nullptr;
     beginInsertRows(ind, parent->childList().count(), parent->childList().count() + dlist.count() - 1);
     svn::StatusEntries::iterator it = dlist.begin();
 #ifdef DEBUG_TIMER
@@ -558,7 +560,7 @@ bool SvnItemModel::dropUrls(const QList<QUrl> &data, Qt::DropAction action, int
 QMimeData *SvnItemModel::mimeData(const QModelIndexList &indexes)const
 {
     QList<QUrl> urls;
-    foreach (const QModelIndex &index, indexes) {
+    for (const QModelIndex &index : indexes) {
         if (index.column() == 0) {
             urls << m_Data->nodeForIndex(index)->kdeName(m_Data->m_Display->baseRevision());
         }
@@ -567,8 +569,8 @@ QMimeData *SvnItemModel::mimeData(const QModelIndexList &indexes)const
     mimeData->setUrls(urls);
 
     KUrlMimeData::MetaDataMap metaMap;
-    metaMap["kdesvn-source"] = QLatin1Char('t');
-    metaMap["kdesvn-id"] = uniqueIdentifier();
+    metaMap[QStringLiteral("kdesvn-source")] = QLatin1Char('t');
+    metaMap[QStringLiteral("kdesvn-id")] = uniqueIdentifier();
     KUrlMimeData::setMetaData(metaMap, mimeData);
 
     return mimeData;
@@ -607,15 +609,20 @@ bool SvnItemModel::refreshItem(SvnItemModelNode *item)
     return true;
 }
 
-bool SvnItemModel::refreshIndex(const QModelIndex &ind, bool sendSignal)
+bool SvnItemModel::refreshIndex(const QModelIndex &idx)
 {
-    bool ret = refreshItem(m_Data->nodeForIndex(ind));
-    if (sendSignal) {
-        emit dataChanged(ind, ind);
-    }
+    bool ret = refreshItem(m_Data->nodeForIndex(idx));
+    emitDataChangedRow(idx);
     return ret;
 }
 
+void SvnItemModel::emitDataChangedRow(const QModelIndex &idx)
+{
+    const auto colS(index(idx.row(), 0, idx.parent()));
+    const auto colE(index(idx.row(), columnCount() - 1, idx.parent()));
+    emit dataChanged(colS, colE);
+}
+
 SvnItemModelNode *SvnItemModel::findPath(const svn::Path &_p)
 {
     QString ip = _p.path();
@@ -627,13 +634,13 @@ SvnItemModelNode *SvnItemModel::findPath(const svn::Path &_p)
             return n1;
         }
         if (!n1->isDir()) {
-            return 0;
+            return nullptr;
         }
-        QStringList lp = ip.split('/', QString::SkipEmptyParts);
+        const QVector<QStringRef> lp = ip.splitRef(QLatin1Char('/'), QString::SkipEmptyParts);
         SvnItemModelNodeDir *d1 = static_cast<SvnItemModelNodeDir *>(n1);
         return d1->findPath(lp);
     }
-    return 0;
+    return nullptr;
 }
 
 QModelIndex SvnItemModel::findIndex(const svn::Path &_p)
@@ -644,12 +651,12 @@ QModelIndex SvnItemModel::findIndex(const svn::Path &_p)
 void SvnItemModel::initDirWatch()
 {
     delete m_Data->m_DirWatch;
-    m_Data->m_DirWatch = 0;
+    m_Data->m_DirWatch = nullptr;
     if (m_Data->m_Display->isWorkingCopy()) {
         m_Data->m_DirWatch = new KDirWatch(this);
-        connect(m_Data->m_DirWatch, SIGNAL(dirty(QString)), this, SLOT(slotDirty(QString)));
-        connect(m_Data->m_DirWatch, SIGNAL(created(QString)), this, SLOT(slotCreated(QString)));
-        connect(m_Data->m_DirWatch, SIGNAL(deleted(QString)), this, SLOT(slotDeleted(QString)));
+        connect(m_Data->m_DirWatch, &KDirWatch::dirty, this, &SvnItemModel::slotDirty);
+        connect(m_Data->m_DirWatch, &KDirWatch::created, this, &SvnItemModel::slotCreated);
+        connect(m_Data->m_DirWatch, &KDirWatch::deleted, this, &SvnItemModel::slotDeleted);
         if (m_Data->m_DirWatch) {
             m_Data->m_DirWatch->addDir(m_Data->m_Display->baseUri() + QLatin1Char('/'), KDirWatch::WatchDirOnly);
             m_Data->m_DirWatch->startScan(true);
@@ -869,17 +876,17 @@ bool SvnItemModel::refreshDirnode(SvnItemModelNodeDir *node, bool check_empty, b
 
     // make sure that we do not read in the whole tree when just refreshing the current tree.
     if (!node->m_Children.isEmpty() && !notrec) {
-        for (int i = 0; i < node->m_Children.size(); ++i) {
-            if (node->m_Children[i]->NodeIsDir()) {
+        for (auto &child : node->m_Children) {
+            if (child->NodeIsDir()) {
                 // both other parameters makes no sense at this point - defaults
-                refreshDirnode(static_cast<SvnItemModelNodeDir *>(node->m_Children[i]), false, false);
+                refreshDirnode(static_cast<SvnItemModelNodeDir *>(child), false, false);
             }
         }
     }
     // after so we don't recurse about it.
     insertDirs(node, dlist);
     if (!dlist.isEmpty()) {
-        itemsFetched(m_Data->indexForNode(node));
+        emit itemsFetched(m_Data->indexForNode(node));
     }
     return true;
 }
@@ -898,9 +905,9 @@ int SvnItemModel::checkUnversionedDirs(SvnItemModelNode *_parent)
     }
     svn::StatusEntries dlist;
     SvnItemModelNodeDir *n = static_cast<SvnItemModelNodeDir *>(_parent);
-    for (QFileInfoList::size_type i = 0; i < list.size(); ++i) {
-        if (!(n->contains(list[i].absoluteFilePath()) || list[i].absoluteFilePath() == n->fullName())) {
-            svn::StatusPtr stat(new svn::Status(list[i].absoluteFilePath()));
+    for (const auto &fi : list) {
+        if (!(n->contains(fi.absoluteFilePath()) || fi.absoluteFilePath() == n->fullName())) {
+            svn::StatusPtr stat(new svn::Status(fi.absoluteFilePath()));
             dlist.append(stat);
         }
     }
