@@ -23,38 +23,10 @@
 #include "svnitemnode.h"
 #include "settings/kdesvnsettings.h"
 
-SvnSortFilterProxy::SvnSortFilterProxy(QObject *parent)
-    : QSortFilterProxyModel(parent), m_sourceModel(0), m_order(Qt::AscendingOrder), m_ShowFilter(svnmodel::All)
+void SvnSortFilterProxy::setSourceModel(QAbstractItemModel *sourceModel)
 {
-}
-
-SvnSortFilterProxy::~SvnSortFilterProxy()
-{
-}
-
-void SvnSortFilterProxy::sort(int column, Qt::SortOrder order)
-{
-    m_order = order;
-    QSortFilterProxyModel::sort(column, order);
-}
-
-bool SvnSortFilterProxy::hasChildren(const QModelIndex &parent)const
-{
-    if (!parent.isValid()) {
-        return true;
-    }
-    if (m_sourceModel) {
-        QModelIndex ind = mapToSource(parent);
-        return m_sourceModel->hasChildren(ind);
-    } else {
-        return QSortFilterProxyModel::hasChildren(parent);
-    }
-}
-
-void SvnSortFilterProxy::setSourceSvnModel(SvnItemModel *sourceModel)
-{
-    m_sourceModel = sourceModel;
-    setSourceModel(sourceModel);
+    m_sourceModel = qobject_cast<SvnItemModel*>(sourceModel);
+    QSortFilterProxyModel::setSourceModel(sourceModel);
 }
 
 bool SvnSortFilterProxy::lessThan(const QModelIndex &left, const QModelIndex &right)const
@@ -62,9 +34,9 @@ bool SvnSortFilterProxy::lessThan(const QModelIndex &left, const QModelIndex &ri
     if (!(left.isValid() && right.isValid())) {
         return QSortFilterProxyModel::lessThan(left, right);
     }
-    SvnItemModelNode *n1, *n2;
-    n1 = static_cast<SvnItemModelNode *>(left.internalPointer());
-    n2 = static_cast<SvnItemModelNode *>(right.internalPointer());
+
+    SvnItemModelNode *n1 = static_cast<SvnItemModelNode *>(left.internalPointer());
+    SvnItemModelNode *n2 = static_cast<SvnItemModelNode *>(right.internalPointer());
     /*
      * when having valid model indexes the internal pointer MUST be valid, too.
      * so we may skip if for this.
@@ -77,7 +49,7 @@ bool SvnSortFilterProxy::lessThan(const QModelIndex &left, const QModelIndex &ri
         return QSortFilterProxyModel::lessThan(left, right);
     }
     // we want folders always @first
-    if (m_order == Qt::AscendingOrder) {
+    if (sortOrder() == Qt::AscendingOrder) {
         return n1->sortChar() < n2->sortChar();
     } else {
         return n1->sortChar() > n2->sortChar();
@@ -95,4 +67,5 @@ bool SvnSortFilterProxy::filterAcceptsRow(int source_row, const QModelIndex &sou
 void SvnSortFilterProxy::setShowFilter(svnmodel::ItemTypeFlag fl)
 {
     m_ShowFilter = fl;
+    invalidateFilter();
 }
