@@ -41,7 +41,7 @@ void OpenContextmenu::setup()
 {
     m_mapPopup.clear();
     QStringList _found;
-    Q_FOREACH(const KService::Ptr &ptr, m_List) {
+    for (const KService::Ptr &ptr : qAsConst(m_List)) {
         if (_found.contains(ptr->name())) {
             continue;
         }
@@ -53,7 +53,7 @@ void OpenContextmenu::setup()
 
         m_mapPopup.push_back(ptr);
     }
-    connect(this, SIGNAL(triggered(QAction*)), this, SLOT(slotRunService(QAction*)));
+    connect(this, &QMenu::triggered, this, &OpenContextmenu::slotRunService);
     if (!m_List.isEmpty()) {
         addSeparator();
     }
