@@ -46,11 +46,11 @@ SvnLogDlgImp::SvnLogDlgImp(SvnActions *ac, bool modal, QWidget *parent)
     m_pbClose->setShortcut(Qt::CTRL | Qt::Key_Return);
     KStandardGuiItem::assign(m_pbClose, KStandardGuiItem::Close);
     KStandardGuiItem::assign(m_pbHelp, KStandardGuiItem::Help);
-    m_DispPrevButton->setIcon(QIcon::fromTheme("kdesvndiff"));
-    m_DispSpecDiff->setIcon(QIcon::fromTheme("kdesvndiff"));
-    buttonBlame->setIcon(QIcon::fromTheme("kdesvnblame"));
-    m_SortModel = 0;
-    m_CurrentModel = 0;
+    m_DispPrevButton->setIcon(QIcon::fromTheme(QStringLiteral("kdesvndiff")));
+    m_DispSpecDiff->setIcon(QIcon::fromTheme(QStringLiteral("kdesvndiff")));
+    buttonBlame->setIcon(QIcon::fromTheme(QStringLiteral("kdesvnblame")));
+    m_SortModel = nullptr;
+    m_CurrentModel = nullptr;
     m_ControlKeyDown = false;
 
     if (Kdesvnsettings::self()->log_always_list_changed_files()) {
@@ -88,16 +88,16 @@ void SvnLogDlgImp::dispLog(const svn::LogEntriesMapPtr &log, const QString &what
     m_startRevButton->setNoWorking(m_PegUrl.isUrl());
     m_endRevButton->setNoWorking(m_PegUrl.isUrl());
     if (!m_PegUrl.isUrl() || Kdesvnsettings::remote_special_properties()) {
-        QString s = m_Actions->searchProperty(_bugurl, "bugtraq:url", pegUrl, peg, true);
+        QString s = m_Actions->searchProperty(_bugurl, QStringLiteral("bugtraq:url"), pegUrl, peg, true);
         if (!s.isEmpty()) {
             QString reg;
-            s = m_Actions->searchProperty(reg, "bugtraq:logregex", pegUrl, peg, true);
+            s = m_Actions->searchProperty(reg, QStringLiteral("bugtraq:logregex"), pegUrl, peg, true);
             if (!s.isNull() && !reg.isEmpty()) {
-                const QStringList s1 = reg.split(QLatin1Char('\n'));
+                const QVector<QStringRef> s1 = reg.splitRef(QLatin1Char('\n'));
                 if (!s1.isEmpty()) {
-                    _r1.setPattern(s1.at(0));
+                    _r1.setPattern(s1.at(0).toString());
                     if (s1.size() > 1) {
-                        _r2.setPattern(s1.at(1));
+                        _r2.setPattern(s1.at(1).toString());
                     }
                 }
             }
@@ -106,9 +106,9 @@ void SvnLogDlgImp::dispLog(const svn::LogEntriesMapPtr &log, const QString &what
     _base = root;
     m_Entries = log;
     if (!what.isEmpty()) {
-        setWindowTitle(i18n("SVN Log of %1", what));
+        setWindowTitle(i18nc("@title:window", "SVN Log of %1", what));
     } else {
-        setWindowTitle(i18n("SVN Log"));
+        setWindowTitle(i18nc("@title:window", "SVN Log"));
     }
     _name = what;
     if (!_name.startsWith(QLatin1Char('/'))) {
@@ -135,8 +135,8 @@ void SvnLogDlgImp::dispLog(const svn::LogEntriesMapPtr &_log)
     if (must_init) {
         m_LogTreeView->setModel(m_SortModel);
         m_LogTreeView->sortByColumn(SvnLogModel::Revision, Qt::DescendingOrder);
-        connect(m_LogTreeView->selectionModel(), SIGNAL(selectionChanged(QItemSelection,QItemSelection)),
-                this, SLOT(slotSelectionChanged(QItemSelection,QItemSelection)));
+        connect(m_LogTreeView->selectionModel(), &QItemSelectionModel::selectionChanged,
+                this, &SvnLogDlgImp::slotSelectionChanged);
         m_LogTreeView->resizeColumnToContents(SvnLogModel::Revision);
         m_LogTreeView->resizeColumnToContents(SvnLogModel::Author);
         m_LogTreeView->resizeColumnToContents(SvnLogModel::Date);
@@ -153,13 +153,13 @@ void SvnLogDlgImp::dispLog(const svn::LogEntriesMapPtr &_log)
 
 QString SvnLogDlgImp::genReplace(const QString &r1match)
 {
-    static QString anf("<a href=\"");
-    static QString mid("\">");
-    static QString end("</a>");
+    static QString anf(QStringLiteral("<a href=\""));
+    static QString mid(QStringLiteral("\">"));
+    static QString end(QStringLiteral("</a>"));
     QString res;
     if (_r2.pattern().length() < 1) {
         res = _bugurl;
-        res.replace("%BUGID%", _r1.cap(1));
+        res.replace(QStringLiteral("%BUGID%"), _r1.cap(1));
         res = anf + res + mid + r1match + end;
         return res;
     }
@@ -177,7 +177,7 @@ QString SvnLogDlgImp::genReplace(const QString &r1match)
         res += r1match.midRef(oldpos, pos - oldpos);
         QString sub = r1match.mid(pos, count);
         QString _url = _bugurl;
-        _url.replace("%BUGID%", sub);
+        _url.replace(QStringLiteral("%BUGID%"), sub);
         res += anf + _url + mid + sub + end;
     }
     res += r1match.midRef(oldpos);
@@ -432,13 +432,13 @@ void SvnLogDlgImp::slotCustomContextMenu(const QPoint &e)
     QAction *ac;
     bool unset = false;
     if (row != m_CurrentModel->rightRow()) {
-        ac = popup.addAction(QIcon::fromTheme("kdesvnright"), i18n("Set version as right side of diff"));
+        ac = popup.addAction(QIcon::fromTheme(QStringLiteral("kdesvnright")), i18n("Set version as right side of diff"));
         ac->setData(101);
     } else {
         unset = true;
     }
     if (row != m_CurrentModel->leftRow()) {
-        ac = popup.addAction(QIcon::fromTheme("kdesvnleft"), i18n("Set version as left side of diff"));
+        ac = popup.addAction(QIcon::fromTheme(QStringLiteral("kdesvnleft")), i18n("Set version as left side of diff"));
         ac->setData(102);
     } else {
         unset = true;
@@ -497,18 +497,16 @@ void SvnLogDlgImp::slotChangedPathContextMenu(const QPoint &e)
     if (!ind.isValid()) {
         return;
     }
-    qlonglong rev = m_CurrentModel->toRevision(ind);
+    const qlonglong rev = m_CurrentModel->toRevision(ind);
     QMenu popup;
-    QString name = item->path();
-    QString action = item->action();
-    QString source = item->revision() > -1 ? item->source() : item->path();
-    svn_revnum_t prev = item->revision() > 0 ? item->revision() : rev - 1;
+    const QString name = item->path();
+    const QString source = item->revision() > -1 ? item->source() : item->path();
     QAction *ac;
     ac = popup.addAction(i18n("Annotate"));
     if (ac) {
         ac->setData(101);
     }
-    if (action != "A" || item->revision() > -1) {
+    if (item->action() != 'A' || item->revision() > -1) {
         ac = popup.addAction(i18n("Diff previous"));
         if (ac) {
             ac->setData(102);
@@ -530,6 +528,7 @@ void SvnLogDlgImp::slotChangedPathContextMenu(const QPoint &e)
         break;
     }
     case 102: {
+        const svn_revnum_t prev = item->revision() > 0 ? item->revision() : rev - 1;
         emit makeDiff(_base + source, prev, _base + name, rev, this);
         break;
     }
@@ -547,17 +546,15 @@ void SvnLogDlgImp::slotSingleDoubleClicked(QTreeWidgetItem *_item, int)
         return;
     }
 
-    LogChangePathItem *item = static_cast<LogChangePathItem *>(_item);
-    QModelIndex ind = selectedRow();
+    const LogChangePathItem *item = static_cast<LogChangePathItem *>(_item);
+    const QModelIndex ind = selectedRow();
     if (!ind.isValid()) {
         return;
     }
-    qlonglong rev = m_CurrentModel->toRevision(ind);
-
-    QString name = item->path();
-    QString action = item->action();
     svn::Revision start(svn::Revision::START);
-    if (action != "D") {
+    if (item->action() != 'D') {
+        const QString name = item->path();
+        const qlonglong rev = m_CurrentModel->toRevision(ind);
         m_Actions->makeBlame(start, rev, _base + name, QApplication::activeModalWidget(), rev, this);
     }
 }
