@@ -62,7 +62,7 @@ static svn_error_t *ProplistReceiver(void *baton, const char *path, apr_hash_t *
 
     ContextP l_context = _baton->m_context;
     if (!l_context) {
-        return svn_error_create(SVN_ERR_CANCELLED, 0, QCoreApplication::translate("svnqt", "Cancelled by user.").toUtf8());
+        return svn_error_create(SVN_ERR_CANCELLED, nullptr, QCoreApplication::translate("svnqt", "Cancelled by user.").toUtf8());
     }
     svn_client_ctx_t *ctx = l_context->ctx();
     if (ctx && ctx->cancel_func) {
@@ -99,7 +99,7 @@ Client_impl::proplist(const Path &path,
             &baton,
             *m_context,
             pool);
-    if (error != NULL) {
+    if (error != nullptr) {
         throw ClientException(error);
     }
 
@@ -120,11 +120,7 @@ Client_impl::propget(const QString &propName,
     apr_hash_t *props;
     svn_revnum_t actual = svn_revnum_t(-1);
     // todo svn 1.8: svn_client_propget5
-#if SVN_API_VERSION >= SVN_VERSION_CHECK(1,7,0)
     svn_error_t *error = svn_client_propget4(&props,
-#else
-    svn_error_t *error = svn_client_propget3(&props,
-#endif
                                              propName.toUtf8(),
                                              path.cstr(),
                                              peg.revision(),
@@ -133,13 +129,11 @@ Client_impl::propget(const QString &propName,
                                              internal::DepthToSvn(depth),
                                              changelists.array(pool),
                                              *m_context,
-#if SVN_API_VERSION >= SVN_VERSION_CHECK(1,7,0)
                                              pool,
-#endif
                                              pool
                                             );
 
-    if (error != NULL) {
+    if (error != nullptr) {
         throw ClientException(error);
     }
 
@@ -153,16 +147,9 @@ Client_impl::propget(const QString &propName,
         const void *key;
         void *val;
 
-        apr_hash_this(hi, &key, NULL, &val);
+        apr_hash_this(hi, &key, nullptr, &val);
         prop_map[propName] = QString::fromUtf8(((const svn_string_t *)val)->data);
         QString filename = QString::fromUtf8((const char *)key);
-#if SVN_API_VERSION < SVN_VERSION_CHECK(1,7,0)
-        // svn_client_propget3 returns relative paths if a relative path was given
-        // we always want to return an absolute path
-        if (!svn_path_is_url(path.cstr()) && !QDir(path).isAbsolute()) {
-            filename = path.path() + QLatin1Char('/') + filename;
-        }
-#endif
         path_prop_map_list.push_back(PathPropertiesMapEntry(filename, prop_map));
     }
 
@@ -176,13 +163,12 @@ Client_impl::propset(const PropertiesParameter &params)
     const svn_string_t *propval;
 
     if (params.propertyValue().isNull()) {
-        propval = 0;
+        propval = nullptr;
     } else {
         propval = svn_string_create(params.propertyValue().toUtf8(), pool);
     }
 
-    svn_error_t *error = 0;
-#if SVN_API_VERSION >= SVN_VERSION_CHECK(1,6,0)
+    svn_error_t *error = nullptr;
     const QByteArray tgtTmp = params.path().cstr();
     if (svn_path_is_url(tgtTmp)) {
         error = svn_client_propset_remote(params.propertyName().toUtf8(),
@@ -191,8 +177,8 @@ Client_impl::propset(const PropertiesParameter &params)
                                           params.skipCheck(),
                                           params.revision(),
                                           map2hash(params.revisionProperties(), pool),
-                                          NULL, // we don't need a commit info - ignore
-                                          NULL,
+                                          nullptr, // we don't need a commit info - ignore
+                                          nullptr,
                                           *m_context,
                                           pool
                                           );
@@ -210,19 +196,8 @@ Client_impl::propset(const PropertiesParameter &params)
                                          pool);
 
     }
-#else
-    svn_commit_info_t *commit_info;
-    error = svn_client_propset3(
-        &commit_info,
-        params.propertyName().toUtf8(),
-        propval, params.path().cstr(),
-        internal::DepthToSvn(params.depth()), params.skipCheck(),
-        params.revision(),
-        params.changeList().array(pool),
-        map2hash(params.revisionProperties(), pool),
-        *m_context, pool);
-#endif
-    if (error != NULL) {
+
+    if (error != nullptr) {
         throw ClientException(error);
     }
 }
@@ -256,7 +231,7 @@ Client_impl::revproplist(const Path &path,
                                 &revnum,
                                 *m_context,
                                 pool);
-    if (error != NULL) {
+    if (error != nullptr) {
         throw ClientException(error);
     }
 
@@ -268,7 +243,7 @@ Client_impl::revproplist(const Path &path,
         const void *key;
         void *val;
 
-        apr_hash_this(hi, &key, NULL, &val);
+        apr_hash_this(hi, &key, nullptr, &val);
         prop_map[ QString::fromUtf8((const char *)key) ] = QString::fromUtf8(((const svn_string_t *)val)->data);
     }
 
@@ -303,12 +278,12 @@ Client_impl::revpropget(const QString &propName,
             &revnum,
             *m_context,
             pool);
-    if (error != NULL) {
+    if (error != nullptr) {
         throw ClientException(error);
     }
 
     // if the property does not exist NULL is returned
-    if (propval == NULL) {
+    if (propval == nullptr) {
         return QPair<qlonglong, QString>(0, QString());
     }
 
@@ -321,12 +296,11 @@ Client_impl::revpropset(const PropertiesParameter &param)
     Pool pool;
 
     const svn_string_t *propval
-        = param.propertyValue().isNull() ? 0 : svn_string_create(param.propertyValue().toUtf8(), pool);
+        = param.propertyValue().isNull() ? nullptr : svn_string_create(param.propertyValue().toUtf8(), pool);
 
     svn_revnum_t revnum;
 
-#if SVN_API_VERSION >= SVN_VERSION_CHECK(1,6,0)
-    const svn_string_t *oldpropval = param.propertyOriginalValue().isNull() ? 0 : svn_string_create(param.propertyOriginalValue().toUtf8(), pool);
+    const svn_string_t *oldpropval = param.propertyOriginalValue().isNull() ? nullptr : svn_string_create(param.propertyOriginalValue().toUtf8(), pool);
     svn_error_t *error = svn_client_revprop_set2(
                              param.propertyName().toUtf8(),
                              propval,
@@ -337,18 +311,8 @@ Client_impl::revpropset(const PropertiesParameter &param)
                              param.force(),
                              *m_context,
                              pool);
-#else
-    svn_error_t *error = svn_client_revprop_set(
-                             param.propertyName().toUtf8(),
-                             propval,
-                             param.path().cstr(),
-                             param.revision().revision(),
-                             &revnum,
-                             param.force(),
-                             *m_context,
-                             pool);
-#endif
-    if (error != NULL) {
+
+    if (error != nullptr) {
         throw ClientException(error);
     }
 
@@ -364,11 +328,10 @@ Client_impl::revpropdel(const QString &propName,
 
     svn_revnum_t revnum;
     svn_error_t *error =
-#if SVN_API_VERSION >= SVN_VERSION_CHECK(1,6,0)
         svn_client_revprop_set2(
             propName.toUtf8(),
-            0, // value = NULL
-            0,
+            nullptr, // value = NULL
+            nullptr,
             path.cstr(),
             revision.revision(),
             &revnum,
@@ -376,18 +339,7 @@ Client_impl::revpropdel(const QString &propName,
             *m_context,
             pool);
 
-#else
-        svn_client_revprop_set(
-            propName.toUtf8(),
-            0, // value = NULL
-            path.cstr(),
-            revision.revision(),
-            &revnum,
-            false,
-            *m_context,
-            pool);
-#endif
-    if (error != NULL) {
+    if (error != nullptr) {
         throw ClientException(error);
     }
 
