@@ -40,8 +40,6 @@ protected:
     void init_clean();
 public:
     Entry_private();
-    Entry_private(const Entry_private &src);
-    virtual ~Entry_private();
 
     bool m_valid;
     LockEntry m_Lock;
@@ -56,13 +54,8 @@ public:
     /**
     * initializes the members
     */
-#if SVN_API_VERSION >= SVN_VERSION_CHECK(1,7,0)
     void
     init(const svn_client_status_t *src);
-#else
-    void
-    init(const svn_wc_entry_t *src);
-#endif
     void
     init(const Entry_private &src);
     void
@@ -78,7 +71,7 @@ void Entry_private::init_clean()
     _repos.clear();
     _uuid.clear();
     _cmt_author.clear();
-    _revision = _cmt_rev = -1;
+    _revision = _cmt_rev = SVN_INVALID_REVNUM;
     _kind = svn_node_unknown;
     _cmt_date = DateTime();
     _copied = false;
@@ -90,18 +83,6 @@ Entry_private::Entry_private()
     init_clean();
 }
 
-Entry_private::Entry_private(const Entry_private &src)
-    : m_valid(false), m_Lock()
-{
-    init_clean();
-    init(src);
-}
-
-Entry_private::~Entry_private()
-{
-}
-
-#if SVN_API_VERSION >= SVN_VERSION_CHECK(1,7,0)
 void
 Entry_private::init(const svn_client_status_t *src)
 {
@@ -124,29 +105,6 @@ Entry_private::init(const svn_client_status_t *src)
         init_clean();
     }
 }
-#else
-void
-Entry_private::init(const svn_wc_entry_t *src)
-{
-    if (src) {
-        // copy & convert the contents of src
-        _name = QString::fromUtf8(src->name);
-        _revision = src->revision;
-        _url = QString::fromEncoded(src->url);
-        _repos = QString::fromEncoded(src->repos);
-        _uuid = QString::fromUtf8(src->uuid);
-        _kind = src->kind;
-        _copied = src->copied != 0;
-        _cmt_rev = src->cmt_rev;
-        _cmt_date = src->cmt_date;
-        _cmt_author = QString::fromUtf8(src->cmt_author);
-        m_Lock.init(src);
-        m_valid = true;
-    } else {
-        init_clean();
-    }
-}
-#endif
 
 void
 Entry_private::init(const Entry_private &src)
@@ -167,7 +125,7 @@ Entry_private::init(const Entry_private &src)
 
 void Entry_private::init(const QString &url, const DirEntry &dirEntry)
 {
-    init(0);
+    init_clean();
     _url = QUrl(url);
     if (!dirEntry.isEmpty()) {
         _name = dirEntry.name();
@@ -183,7 +141,7 @@ void Entry_private::init(const QString &url, const DirEntry &dirEntry)
 
 void Entry_private::init(const QString &url, const InfoEntry &src)
 {
-    init(0);
+    init(nullptr);
     _name = src.Name();
     _url = QUrl(url);
     _revision = src.revision();
@@ -195,11 +153,7 @@ void Entry_private::init(const QString &url, const InfoEntry &src)
     m_valid = true;
 }
 
-#if SVN_API_VERSION >= SVN_VERSION_CHECK(1,7,0)
 Entry::Entry(const svn_client_status_t *src)
-#else
-Entry::Entry(const svn_wc_entry_t *src)
-#endif
     : m_Data(new Entry_private())
 {
     m_Data->init(src);
@@ -211,7 +165,7 @@ Entry::Entry(const Entry &src)
     if (src.m_Data) {
         m_Data->init(*(src.m_Data));
     } else {
-        m_Data->init(0);
+        m_Data->init(nullptr);
     }
 }
 
@@ -241,7 +195,7 @@ Entry::operator = (const Entry &src)
     if (src.m_Data) {
         m_Data->init(*(src.m_Data));
     } else {
-        m_Data->init(0);
+        m_Data->init(nullptr);
     }
     return *this;
 }
