@@ -34,9 +34,7 @@
 
 // subversion api
 #include <svn_path.h>
-#if SVN_API_VERSION >= SVN_VERSION_CHECK(1,6,0)
 #include <svn_dirent_uri.h>
-#endif
 
 // apr api
 #include <apr_file_io.h>
@@ -58,16 +56,6 @@ Path::Path(const QString &path)
     init(path);
 }
 
-Path::Path(const QUrl &path)
-{
-    init(path.toString());
-}
-
-Path::Path(const Path &path)
-    : m_path(path.m_path)
-{
-}
-
 void
 Path::init(const QString &path)
 {
@@ -83,29 +71,11 @@ Path::init(const QString &path)
                 int_path = svn_path_uri_encode(int_path, pool);
             }
         } else {
-#if SVN_API_VERSION >= SVN_VERSION_CHECK(1,6,0)
             int_path = svn_dirent_internal_style(int_path, pool.pool());
-#else
-            int_path = svn_path_internal_style(int_path, pool.pool());
-#endif
         }
 
         m_path = QString::fromUtf8(int_path);
-        /* the following block is a problem and thats why commented out: since a while subversion raises
-         * an assert because of wrong url if replacing the @ sign with entity and kdesvn dies.
-         * So using the scheme on ubuntu that it just don't display the content of such a folder/file.
-         */
-        /*
-         if (Url::isValid(m_path) && m_path.indexOf("@")!=-1 ) {
-          /// @todo make sure that "@" is never used as revision parameter
-          QUrl uri = m_path;
-          m_path = uri.path();
-          m_path.replace('@',"%40");
-          m_path = uri.scheme()+"://"+uri.authority()+m_path;
-        }
-        */
-
-        while (m_path.endsWith(QLatin1Char('/'))) {
+        while (m_path.endsWith(QLatin1Char('/')) && m_path.size() > 1) {
             m_path.chop(1);
         }
     }
@@ -139,7 +109,7 @@ Path::operator=(const Path &path)
 }
 
 bool
-Path::isset() const
+Path::isSet() const
 {
     return !m_path.isEmpty();
 }
@@ -154,11 +124,7 @@ Path::addComponent(const QString &_component)
     }
     if (Url::isValid(m_path)) {
         const char *newPath =
-#if SVN_API_VERSION >= SVN_VERSION_CHECK(1,6,0)
             svn_path_url_add_component2(m_path.toUtf8(), component.toUtf8(), pool);
-#else
-            svn_path_url_add_component(m_path.toUtf8(), component.toUtf8(), pool);
-#endif
         m_path = QString::fromUtf8(newPath);
     } else {
         svn_stringbuf_t *pathStringbuf =
@@ -187,12 +153,12 @@ void
 Path::parsePeg(const QString &pathorurl, Path &_path, svn::Revision &_peg)
 {
     const QByteArray _buf = pathorurl.toUtf8();
-    const char *truepath = 0;
+    const char *truepath = nullptr;
     svn_opt_revision_t pegr;
 
     Pool pool;
     svn_error_t *error = svn_opt_parse_path(&pegr, &truepath, _buf, pool);
-    if (error != 0) {
+    if (error != nullptr) {
         throw ClientException(error);
     }
     //qDebug("Path: %s",truepath);
@@ -213,11 +179,7 @@ Path::native() const
         return m_path;
     }
     Pool pool;
-#if SVN_API_VERSION >= SVN_VERSION_CHECK(1,6,0)
     return QString::fromUtf8(svn_dirent_local_style(m_path.toUtf8(), pool));
-#else
-    return QString::fromUtf8(svn_path_local_style(m_path.toUtf8(), pool));
-#endif
 }
 
 }
