@@ -60,7 +60,7 @@ public:
      * \param ctx a client context for calls to cancel_func inside. you should this only set with functions not using it itself
      * like svn_client_cat2:
      */
-    explicit SvnStream(bool readit, bool writeit, svn_client_ctx_t *ctx = 0);
+    explicit SvnStream(bool readit, bool writeit, svn_client_ctx_t *ctx = nullptr);
     //! frees all structures and releases memory pool.
     virtual ~SvnStream();
 
@@ -132,7 +132,7 @@ public:
      * \param ctx a client context for calls to cancel_func inside. you should this only set with functions not using it itself
      * like svn_client_cat2:
      */
-    explicit SvnByteStream(svn_client_ctx_t *ctx = 0);
+    explicit SvnByteStream(svn_client_ctx_t *ctx = nullptr);
     //! release internal buffer
     ~SvnByteStream();
     //! fill internal buffer with data
