@@ -30,16 +30,12 @@
 
 UrlDlg::UrlDlg(QWidget *parent)
     : QDialog(parent)
-    , m_pbClear(new QPushButton(this))
     , m_urlRequester(nullptr)
     , m_ui(new Ui::UrlDlg)
 {
     m_ui->setupUi(this);
-    m_ui->buttonBox->addButton(m_pbClear, QDialogButtonBox::DestructiveRole);
     m_ui->buttonBox->button(QDialogButtonBox::Ok)->setDefault(true);
     m_ui->buttonBox->button(QDialogButtonBox::Ok)->setShortcut(Qt::CTRL | Qt::Key_Return);
-    m_pbClear->setIcon(QIcon::fromTheme("clear"));
-    m_pbClear->setText(i18n("Clear"));
 
     KHistoryComboBox *combo = new KHistoryComboBox(this);
     combo->setDuplicatesEnabled(false);
@@ -58,14 +54,13 @@ UrlDlg::UrlDlg(QWidget *parent)
     m_ui->topLayout->insertWidget(1, m_urlRequester);
     m_urlRequester->setFocus();
     m_urlRequester->setMode(KFile::ExistingOnly | KFile::Directory);
-    connect(m_urlRequester->comboBox(), SIGNAL(currentTextChanged(QString)),
-            this, SLOT(slotTextChanged(QString)));
+    connect(m_urlRequester->comboBox(), &KComboBox::currentTextChanged,
+            this, &UrlDlg::slotTextChanged);
 
     slotTextChanged(QString());
     m_urlRequester->adjustSize();
 
-    connect(m_ui->buttonBox, SIGNAL(accepted()), this, SLOT(accept()));
-    connect(m_pbClear, SIGNAL(clicked(bool)), m_urlRequester, SLOT(clear()));
+    connect(m_ui->buttonBox, &QDialogButtonBox::accepted, this, &UrlDlg::accept);
 }
 
 UrlDlg::~UrlDlg()
@@ -92,7 +87,6 @@ void UrlDlg::slotTextChanged(const QString &text)
 {
     bool state = !text.trimmed().isEmpty();
     m_ui->buttonBox->button(QDialogButtonBox::Ok)->setEnabled(state);
-    m_pbClear->setEnabled(state);
 }
 
 /*!
@@ -102,7 +96,7 @@ QUrl UrlDlg::getUrl(QWidget *parent)
 {
     QUrl ret;
     QPointer<UrlDlg> dlg(new UrlDlg(parent));
-    dlg->setWindowTitle(i18n("Open"));
+    dlg->setWindowTitle(i18nc("@title:window", "Open"));
     if (dlg->exec() == QDialog::Accepted) {
         // added by Wellu Mäkinen <wellu@wellu.org>
         //
