@@ -26,7 +26,6 @@ namespace Ui
 class UrlDlg;
 }
 class KUrlRequester;
-class QPushButton;
 
 /**
 @author Rajko Albrecht
@@ -35,16 +34,15 @@ class UrlDlg : public QDialog
 {
     Q_OBJECT
 public:
-    static QUrl getUrl(QWidget *parent = 0);
+    static QUrl getUrl(QWidget *parent = nullptr);
 private:
     explicit UrlDlg(QWidget *parent = nullptr);
-    virtual ~UrlDlg();
+    ~UrlDlg();
 
 private slots:
     void accept() override final;
     void slotTextChanged(const QString &);
 private:
-    QPushButton *m_pbClear;
     KUrlRequester *m_urlRequester;
     Ui::UrlDlg *m_ui;
 };
